(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    179271,       3652]*)
(*NotebookOutlinePosition[    179950,       3675]*)
(*  CellTagsIndexPosition[    179906,       3671]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Note-11"
}], "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Lagrangian and Rayleigh's dissipative function in linear motion system\
\>", "Subsubsection"],

Cell["Kinetic energy:", "Text"],

Cell[BoxData[
    \(\(kineticEnergy[m_, x_] := \((1/2)\)*m*\((D[x[t], t]^2)\);\)\)], "Input"],

Cell["Potential energy:", "Text"],

Cell[BoxData[
    \(\(potentialEnergy[k_, x_] := \((1/2)\)*k*\((x[t]^2)\);\)\)], "Input"],

Cell["Lagrangian:", "Text"],

Cell[BoxData[
    \(\(l[m_, k_, x_] := 
        kineticEnergy[m, x] - potentialEnergy[k, x];\)\)], "Input"],

Cell["Rayleigh dissipative function:", "Text"],

Cell[BoxData[
    \(\(f[b_, x_] := \((1/2)\)*b*\((D[x[t], t]^2)\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["System of equations", "Subsubsection"],

Cell["Linear motion system:", "Text"],

Cell[BoxData[
    \(equ[M_, K_, B_] := 
      D[D[l[M, K, x], D[x[t], t]], t] - D[l[M, K, x], x[t]] + 
        D[f[B, x], D[x[t], t]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution of Inhomogeneous Equation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Q*Sin[omg\ t], x[t], t] // 
        Simplify\)], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \[ExponentialE]\^\(-\(\(\((B + \@\(B\^2 - 4\ K\ M\))\)\
\ t\)\/\(2\ M\)\)\)\ C[
                1] + \[ExponentialE]\^\(\(\((\(-B\) + \@\(B\^2 - 4\ K\ M\))\)\
\ t\)\/\(2\ M\)\)\ C[
                2] - \(Q\ \((B\ omg\ Cos[omg\ t] + \((\(-K\) + M\ omg\^2)\)\ \
Sin[omg\ t])\)\)\/\(K\^2 + B\^2\ omg\^2 - 2\ K\ M\ omg\^2 + M\^2\ \
omg\^4\)}}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple Dumping", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Q*Sin[omg\ t], x[t], t] // 
        Simplify\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(\(1\/\((K + M\ omg\^2)\)\^2\)\((\[ExponentialE]\^\(-\
\(\(K\ t\)\/\@\(K\ M\)\)\)\ \((\((K + M\ omg\^2)\)\^2\ \((C[1] + t\ C[2])\) - 
                  2\ \[ExponentialE]\^\(\(K\ t\)\/\@\(K\ M\)\)\ \@\(K\ M\)\ \
omg\ Q\ Cos[omg\ t] + \[ExponentialE]\^\(\(K\ t\)\/\@\(K\ M\)\)\ \((K - 
                        M\ omg\^2)\)\ Q\ Sin[omg\ t])\))\)\)}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Q = 5. ;\)\), "\[IndentingNewLine]", 
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(omg = 2. *Pi*50. ;\)\), "\[IndentingNewLine]", 
    \(\(Con[1] = \(-Q\)/
          Sqrt[\((K - \((omg*M)\)^2)\)^2 + \((omg*
                    B)\)^2];\)\), "\[IndentingNewLine]", 
    \(\(Con[2] = 0. ;\)\), "\[IndentingNewLine]", 
    \(\(B = 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Q*Sin[omg\ t], x[t], t, 
          GeneratedParameters \[Rule] Con] // Simplify\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(-0.000022515801688411904`\)\ \
\[ExponentialE]\^\(\(-0.5773502691896262`\)\ t\) + 
            0.`\ \[ExponentialE]\^\(\(-0.5773502691896253`\)\ t\) + \
\((\(\(0.`\)\(\[InvisibleSpace]\)\) + 
                  0.`\ \[ImaginaryI])\)\ \[ExponentialE]\^\(0.`\ t\)\ Cos[
                314.1592653589793`\ t] - \((\(\(0.000030517578125`\)\(\
\[InvisibleSpace]\)\) + 
                  5.05939938519463`*^-9\ \[ImaginaryI])\)\ \
\[ExponentialE]\^\(0.`\ t\)\ Sin[314.1592653589793`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Re[Evaluate[x[t] /. solution]], {t, 0, 0.1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381 0.516186 9467.38 [
[.21429 .50369 -12 -9 ]
[.21429 .50369 12 0 ]
[.40476 .50369 -12 -9 ]
[.40476 .50369 12 0 ]
[.59524 .50369 -12 -9 ]
[.59524 .50369 12 0 ]
[.78571 .50369 -12 -9 ]
[.78571 .50369 12 0 ]
[.97619 .50369 -9 -9 ]
[.97619 .50369 9 0 ]
[.01131 .04282 -48 -4.5 ]
[.01131 .04282 0 4.5 ]
[.01131 .13749 -48 -4.5 ]
[.01131 .13749 0 4.5 ]
[.01131 .23217 -48 -4.5 ]
[.01131 .23217 0 4.5 ]
[.01131 .32684 -48 -4.5 ]
[.01131 .32684 0 4.5 ]
[.01131 .42151 -48 -4.5 ]
[.01131 .42151 0 4.5 ]
[.01131 .61086 -42 -4.5 ]
[.01131 .61086 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .51619 m
.21429 .52244 L
s
[(0.02)] .21429 .50369 0 1 Mshowa
.40476 .51619 m
.40476 .52244 L
s
[(0.04)] .40476 .50369 0 1 Mshowa
.59524 .51619 m
.59524 .52244 L
s
[(0.06)] .59524 .50369 0 1 Mshowa
.78571 .51619 m
.78571 .52244 L
s
[(0.08)] .78571 .50369 0 1 Mshowa
.97619 .51619 m
.97619 .52244 L
s
[(0.1)] .97619 .50369 0 1 Mshowa
.125 Mabswid
.07143 .51619 m
.07143 .51994 L
s
.11905 .51619 m
.11905 .51994 L
s
.16667 .51619 m
.16667 .51994 L
s
.2619 .51619 m
.2619 .51994 L
s
.30952 .51619 m
.30952 .51994 L
s
.35714 .51619 m
.35714 .51994 L
s
.45238 .51619 m
.45238 .51994 L
s
.5 .51619 m
.5 .51994 L
s
.54762 .51619 m
.54762 .51994 L
s
.64286 .51619 m
.64286 .51994 L
s
.69048 .51619 m
.69048 .51994 L
s
.7381 .51619 m
.7381 .51994 L
s
.83333 .51619 m
.83333 .51994 L
s
.88095 .51619 m
.88095 .51994 L
s
.92857 .51619 m
.92857 .51994 L
s
.25 Mabswid
0 .51619 m
1 .51619 L
s
.02381 .04282 m
.03006 .04282 L
s
[(-0.00005)] .01131 .04282 1 0 Mshowa
.02381 .13749 m
.03006 .13749 L
s
[(-0.00004)] .01131 .13749 1 0 Mshowa
.02381 .23217 m
.03006 .23217 L
s
[(-0.00003)] .01131 .23217 1 0 Mshowa
.02381 .32684 m
.03006 .32684 L
s
[(-0.00002)] .01131 .32684 1 0 Mshowa
.02381 .42151 m
.03006 .42151 L
s
[(-0.00001)] .01131 .42151 1 0 Mshowa
.02381 .61086 m
.03006 .61086 L
s
[(0.00001)] .01131 .61086 1 0 Mshowa
.125 Mabswid
.02381 .06175 m
.02756 .06175 L
s
.02381 .08069 m
.02756 .08069 L
s
.02381 .09962 m
.02756 .09962 L
s
.02381 .11856 m
.02756 .11856 L
s
.02381 .15643 m
.02756 .15643 L
s
.02381 .17536 m
.02756 .17536 L
s
.02381 .1943 m
.02756 .1943 L
s
.02381 .21323 m
.02756 .21323 L
s
.02381 .2511 m
.02756 .2511 L
s
.02381 .27003 m
.02756 .27003 L
s
.02381 .28897 m
.02756 .28897 L
s
.02381 .3079 m
.02756 .3079 L
s
.02381 .34577 m
.02756 .34577 L
s
.02381 .36471 m
.02756 .36471 L
s
.02381 .38364 m
.02756 .38364 L
s
.02381 .40258 m
.02756 .40258 L
s
.02381 .44045 m
.02756 .44045 L
s
.02381 .45938 m
.02756 .45938 L
s
.02381 .47832 m
.02756 .47832 L
s
.02381 .49725 m
.02756 .49725 L
s
.02381 .53512 m
.02756 .53512 L
s
.02381 .55406 m
.02756 .55406 L
s
.02381 .57299 m
.02756 .57299 L
s
.02381 .59193 m
.02756 .59193 L
s
.02381 .02388 m
.02756 .02388 L
s
.02381 .00495 m
.02756 .00495 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30302 m
.03279 .21883 L
.04262 .13529 L
.04758 .09931 L
.05288 .06688 L
.05789 .04288 L
.06006 .03466 L
.06244 .02719 L
.06507 .02097 L
.0665 .01846 L
.06719 .01748 L
.06785 .01668 L
.0691 .01554 L
.07025 .01492 L
.07148 .01472 L
.07218 .01481 L
.07283 .01504 L
.07354 .01544 L
.0743 .01605 L
.07503 .01679 L
.07569 .01762 L
.07829 .02217 L
.07964 .02534 L
.08112 .02947 L
.0841 .03977 L
.08922 .06326 L
.09469 .096 L
.10458 .17135 L
.12439 .35498 L
.13484 .44824 L
.14057 .49281 L
.14594 .52858 L
.15107 .55619 L
.15578 .57521 L
.15832 .5828 L
.161 .58868 L
.1624 .59087 L
.16369 .59235 L
.16444 .59297 L
.16512 .59338 L
.1659 .59368 L
.16664 .59378 L
.16774 .59361 L
.16896 .59298 L
.17023 .59183 L
.17142 .5903 L
.17354 .58647 L
.17583 .58081 L
.1785 .57221 L
.18103 .56213 L
Mistroke
.18579 .53844 L
.1954 .47381 L
.20563 .38672 L
.22403 .2143 L
.23434 .12821 L
.23976 .09056 L
.24548 .05831 L
.2505 .03721 L
.25335 .02848 L
.25471 .02516 L
.256 .02254 L
.25717 .02061 L
.25844 .01899 L
.2596 .01796 L
.26067 .01738 L
.26182 .01715 L
.26309 .01739 L
.26373 .0177 L
.26442 .01818 L
.26567 .01942 L
.26693 .02117 L
.26807 .02319 L
.27064 .02918 L
.27302 .0365 L
.27526 .04492 L
.2803 .06894 L
.28575 .10229 L
.30686 .28127 L
.32638 .4594 L
.33173 .50018 L
.33747 .53722 L
.34289 .56466 L
.34523 .57405 L
.34783 .58256 L
.35027 .58872 L
.35161 .59133 L
.35286 .59328 L
.35403 .59465 L
.35511 .59553 L
.35628 .59608 L
.35753 .59619 L
.35879 .5958 L
.35949 .59537 L
.36014 .59484 L
.36138 .59344 L
.36256 .59167 L
.36521 .58614 L
.36808 .57774 L
.37293 .5581 L
.37807 .53033 L
Mistroke
.38728 .46516 L
.40706 .28606 L
.42514 .12824 L
.4299 .09514 L
.4351 .06504 L
.43748 .0536 L
.44001 .04314 L
.44238 .03502 L
.44456 .02902 L
.44586 .02615 L
.44727 .02359 L
.4487 .02165 L
.44948 .02085 L
.45021 .02028 L
.45089 .01989 L
.45155 .01967 L
.45277 .0196 L
.45409 .02005 L
.45483 .02054 L
.45552 .02115 L
.4567 .02255 L
.45781 .02425 L
.46033 .02955 L
.46279 .03658 L
.46545 .04615 L
.47041 .0694 L
.47503 .09679 L
.4855 .17594 L
.50661 .37164 L
.51714 .46409 L
.52231 .50333 L
.52708 .53453 L
.53133 .55768 L
.536 .57751 L
.53843 .58532 L
.5407 .59103 L
.54193 .59346 L
.5431 .59534 L
.54374 .5962 L
.54444 .59698 L
.54567 .59798 L
.54632 .59832 L
.54701 .59854 L
.54824 .59855 L
.54956 .59804 L
.55031 .5975 L
.55101 .59684 L
.55228 .59526 L
.55343 .59338 L
.55603 .58767 L
Mistroke
.55834 .58087 L
.56084 .57171 L
.5654 .55055 L
.57631 .47894 L
.58639 .39331 L
.6067 .20379 L
.61663 .12315 L
.62573 .06665 L
.63019 .04664 L
.63272 .03783 L
.63507 .03134 L
.63623 .02875 L
.63732 .02669 L
.63831 .02513 L
.63936 .02382 L
.64051 .02279 L
.64156 .0222 L
.6427 .02195 L
.64395 .02215 L
.64526 .02289 L
.6465 .02409 L
.64762 .02557 L
.64884 .02763 L
.65156 .03389 L
.65408 .04168 L
.65867 .06058 L
.66355 .08695 L
.67291 .15308 L
.68301 .24095 L
.70129 .41248 L
.71166 .49762 L
.71672 .53183 L
.72132 .55765 L
.72619 .57883 L
.72887 .58758 L
.73139 .59386 L
.73273 .5964 L
.73414 .59848 L
.73535 .59976 L
.73604 .60029 L
.73668 .60064 L
.73742 .6009 L
.73813 .60098 L
.73945 .60071 L
.74018 .60032 L
.74087 .5998 L
.74162 .59907 L
.74242 .5981 L
.74366 .59619 L
.74503 .59354 L
Mistroke
.74779 .58646 L
.75034 .57788 L
.75272 .56817 L
.7581 .54057 L
.76386 .50309 L
.78404 .32859 L
.80388 .14992 L
.80931 .11005 L
.81508 .07488 L
.82001 .05161 L
.82281 .04141 L
.82544 .03395 L
.82777 .02908 L
.8291 .02707 L
.83032 .02569 L
.83163 .02474 L
.83281 .02434 L
.83347 .02431 L
.83418 .02443 L
.83546 .02505 L
.83657 .02599 L
.83779 .02747 L
.83905 .02951 L
.84024 .03186 L
.84236 .03715 L
.84464 .04432 L
.85019 .06805 L
.85546 .09815 L
.86532 .17119 L
.88351 .33821 L
.89387 .43341 L
.90361 .51048 L
.90823 .54044 L
.9131 .56633 L
.91565 .57733 L
.91845 .58723 L
.92099 .59423 L
.92335 .59898 L
.92466 .60087 L
.92535 .60165 L
.92608 .60232 L
.92672 .60276 L
.92742 .6031 L
.92866 .60332 L
.92987 .60307 L
.93116 .6023 L
.93238 .60109 L
.9335 .59958 L
.93488 .59717 L
.93616 .59442 L
Mistroke
.93906 .58633 L
.94162 .57713 L
.94435 .56527 L
.95223 .52003 L
.96075 .45571 L
.97619 .31498 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<P3oool00`000000oooo0?ooo`3[0?ooo`00<P3o
ool200000>`0oooo000b0?ooo`030000003oool0oooo0>/0oooo000b0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0g`3oool00380oooo00<000000?ooo`3oool0203oool3000002/0
oooo0P00002c0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000002X0
oooo00<000000?ooo`000000:`3oool3000002X0oooo0`00001H0?ooo`00<P3oool2000000P0oooo
00D000000?ooo`3oool0oooo0000000Y0?ooo`040000003oool0oooo000002T0oooo00@000000?oo
o`3oool00000:P3oool00`000000oooo0000000Z0?ooo`<00000:`3oool00380oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00D000000?oo
o`3oool0oooo0000000Y0?ooo`050000003oool0oooo0?ooo`000000:03oool010000000oooo0?oo
o`00000Z0?ooo`040000003oool0oooo000002X0oooo00080?ooo`800000103oool2000000@0oooo
0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool01@000000oooo
0?ooo`3oool0000002P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`05
0000003oool0oooo0?ooo`000000:@3oool010000000oooo0?ooo`00000Z0?ooo`001`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000000:03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00070?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3o
ool3000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09`3oool000030?ooo`0000000000008000000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P000004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09`3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`00203oool2000000X0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`<000000`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo000b0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool09P3oool00380oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo000b
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`00<P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02D0oooo000b0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`00<P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo000b0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool09@3oool00380oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0T0?ooo`00<P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0
oooo000b0?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`00<P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02@0oooo000b0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0903oool00380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0T0?oo
o`00<P3oool2000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool00380oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0S0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02<0oooo00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000050?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo02<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`D000000P3oool300000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool000030?ooo`00000000000080
00000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool08`3oool000P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
1@3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`00<P3o
ool200000080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool08P3oool00380oooo00D000000?ooo`3oool0oooo0000
000>0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0R0?ooo`00<P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo000b0?ooo`050000003oool0
oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool08P3oool00380oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`00<P3oool2
00000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool08P3oool00380oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0R
0?ooo`00<P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo000b0?ooo`050000003oool0oooo
0?ooo`0000003`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool08P3oool00380oooo0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo000b0?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0240oooo000b0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0240oooo000b0?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0240oooo000b0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0240oooo000b0?ooo`80
000000<0oooo0000003oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool08@3oool00380oooo00@000000?ooo`3oool000004@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool000P0oooo
0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P0000040?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0240oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`@000004@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool000030?oo
o`0000000000008000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000D0oooo00L000000?ooo`3oool0oooo0000003oool000000180oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00070?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool000000180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0200oooo00080?ooo`8000002P3oool2000000@0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0000001<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0200
oooo000b0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0200oooo000b0?ooo`<000004`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool00380oooo00<00000
0?ooo`0000004`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0803oool00380oooo0P00000D0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0P0?ooo`00<P3oool2000001@0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo000b0?ooo`800000
503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
803oool00380oooo0P00000D0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0P0?ooo`00<P3oool2000001@0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo000b0?ooo`800000503oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3oool00380
oooo0P00000D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0O0?ooo`00<P3oool2000001D0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01l0oooo000b0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo000b
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01l0oooo000b0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo000b0?ooo`80
00005@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool07`3oool00380oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool07`3oool00380oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`8000000`3oool4000000<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`070?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00L0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`<00000503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`070?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`00203oool2000000X0oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00P0oooo000b0?ooo`8000005P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`08
0?ooo`00<P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000b0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00380oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`080?ooo`00<P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00P0oooo000b0?ooo`8000005P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`00<P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo000b0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`090?ooo`00<P3oool2000001L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00380oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00<P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00T0oooo000b0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02@3oool00380oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`00<P3o
ool2000001L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0:0?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000040?ooo`8000000`3oool500000080oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0:0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00X0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`<000005`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0:0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02P3oool000L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00203oool2000000X0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00X0oooo000b0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02P3oool00380oooo0P00000I0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo000b0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02`3oool00380oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0;0?ooo`00<P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo000b0?ooo`8000006@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`00<P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00/0oooo000b0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool00380oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`06
0?ooo`8000000`3oool3000000@0oooo0P0000030?ooo`@00000403oool00`000000oooo0?ooo`05
0?ooo`800000103oool2000000@0oooo0P0000050?ooo`<000003`3oool00`000000oooo0?ooo`06
0?ooo`8000000`3oool3000000@0oooo0P0000030?ooo`<00000403oool00`000000oooo0?ooo`06
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000004@3oool00`000000oooo0?ooo`09
0?ooo`80000000@0oooo0000003oool0oooo0P0000030?ooo`D000000@3oool00380oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000100oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo0040oooo000b0?ooo`8000006P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool50000
00l0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000@0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00@3oool00380oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo0`00000A0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P00000A0?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`01
0?ooo`00<P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
0140oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`050?oo
o`800000103oool200000180oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?oo
o`3oool0103oool2000000D0oooo0P00000A0?ooo`030000003oool0oooo00D0oooo0P0000030?oo
o`030000003oool0oooo00@0oooo0P0000040?ooo`<00000403oool00`000000oooo0?ooo`050?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`800000103oool200000140oooo00<000000?oo
o`3oool02@3oool3000000T0oooo0P0000030?ooo`00<P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00`0oooo000b0?ooo`8000006P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`00<P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo000b0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0=0?ooo`00;@3oooo_000000@0oooo000b0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
000b0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo000b0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`00<P3oool2000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00380oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`00<P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo000b0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0380oooo0P00000M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo000b0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03`3oool00380oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0?0?ooo`00<P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo000b
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00380oooo0P00000N0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0100oooo000b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0403oool00380oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`00000Y0?ooo`05
0000003oool0oooo0?ooo`000000:03oool01@000000oooo0?ooo`3oool0000002P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0403oool00380oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`00000Y
0?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000oooo0?ooo`3oool0000002T0oooo
00D000000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00380oooo0P00000P0?ooo`<00000:P3oool00`000000oooo0000000Z0?ooo`040000
003oool0oooo000002T0oooo00@000000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool0
000001<0oooo000b0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:@3oool30000
02X0oooo0`00000Z0?ooo`040000003oool0oooo000002T0oooo00D000000?ooo`3oool0oooo0000
000C0?ooo`00<P3oool00`000000oooo0?ooo`1j0?ooo`800000:`3oool3000002X0oooo00<00000
0?ooo`000000503oool000P0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?oo
o`800000103oool2000000<0oooo1@0000020?ooo`030000003oool0oooo0=D0oooo0P00000D0?oo
o`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3[0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool300000>/0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>/0oooo0007
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3`0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000040?ooo`800000lP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0224566, -6.04664*^-05, \
0.000440493, 4.43119*^-07}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple Dumping with Two Characteristic Values", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 1 + 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Q*Sin[omg\ t], x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \[ExponentialE]\^\(\(-1.6149642927103738`\)\ t\)\ C[
                1] + \[ExponentialE]\^\(\(-0.2064029123355441`\)\ t\)\ C[
                2] + \[ExponentialE]\^\(\(-2.220446049250313`*^-16\)\ t\)\ \
\((\((\(\(0.007532542997108415`\)\(\[InvisibleSpace]\)\) + 
                        0.`\ \[ImaginaryI])\)\ Cos[
                      314.1592653589793`\ t] - \((\(\(0.007532738798140148`\)\
\(\[InvisibleSpace]\)\) + 
                        0.`\ \[ImaginaryI])\)\ \
\[ExponentialE]\^\(3.3306690738754696`*^-16\ t\)\ Cos[
                      314.1592653589793`\ t] - \((\(\(0.00003872172275337914`\
\)\(\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI])\)\ Sin[
                      314.1592653589793`\ t] + \((4.9490159840502535`*^-6 + 
                        0.`\ \[ImaginaryI])\)\ \
\[ExponentialE]\^\(3.3306690738754696`*^-16\ t\)\ Sin[
                      314.1592653589793`\ t])\)}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(B = 1 + 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Q*Sin[omg\ t], x[t], t, 
        GeneratedParameters \[Rule] Con]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(-0.000022515801688411904`\)\ \
\[ExponentialE]\^\(\(-1.6149642927103738`\)\ t\) + 
            0.`\ \[ExponentialE]\^\(\(-0.2064029123355441`\)\ t\) + \
\[ExponentialE]\^\(\(-2.220446049250313`*^-16\)\ t\)\ \
\((\((\(\(0.007532542997108415`\)\(\[InvisibleSpace]\)\) + 
                        0.`\ \[ImaginaryI])\)\ Cos[
                      314.1592653589793`\ t] - \((\(\(0.007532738798140148`\)\
\(\[InvisibleSpace]\)\) + 
                        0.`\ \[ImaginaryI])\)\ \
\[ExponentialE]\^\(3.3306690738754696`*^-16\ t\)\ Cos[
                      314.1592653589793`\ t] - \((\(\(0.00003872172275337914`\
\)\(\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI])\)\ Sin[
                      314.1592653589793`\ t] + \((4.9490159840502535`*^-6 + 
                        0.`\ \[ImaginaryI])\)\ \
\[ExponentialE]\^\(3.3306690738754696`*^-16\ t\)\ Sin[
                      314.1592653589793`\ t])\)}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 0.1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381 0.482725 8341.41 [
[.21429 .47023 -12 -9 ]
[.21429 .47023 12 0 ]
[.40476 .47023 -12 -9 ]
[.40476 .47023 12 0 ]
[.59524 .47023 -12 -9 ]
[.59524 .47023 12 0 ]
[.78571 .47023 -12 -9 ]
[.78571 .47023 12 0 ]
[.97619 .47023 -9 -9 ]
[.97619 .47023 9 0 ]
[.01131 .06565 -48 -4.5 ]
[.01131 .06565 0 4.5 ]
[.01131 .14907 -48 -4.5 ]
[.01131 .14907 0 4.5 ]
[.01131 .23248 -48 -4.5 ]
[.01131 .23248 0 4.5 ]
[.01131 .3159 -48 -4.5 ]
[.01131 .3159 0 4.5 ]
[.01131 .39931 -48 -4.5 ]
[.01131 .39931 0 4.5 ]
[.01131 .56614 -42 -4.5 ]
[.01131 .56614 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .48273 m
.21429 .48898 L
s
[(0.02)] .21429 .47023 0 1 Mshowa
.40476 .48273 m
.40476 .48898 L
s
[(0.04)] .40476 .47023 0 1 Mshowa
.59524 .48273 m
.59524 .48898 L
s
[(0.06)] .59524 .47023 0 1 Mshowa
.78571 .48273 m
.78571 .48898 L
s
[(0.08)] .78571 .47023 0 1 Mshowa
.97619 .48273 m
.97619 .48898 L
s
[(0.1)] .97619 .47023 0 1 Mshowa
.125 Mabswid
.07143 .48273 m
.07143 .48648 L
s
.11905 .48273 m
.11905 .48648 L
s
.16667 .48273 m
.16667 .48648 L
s
.2619 .48273 m
.2619 .48648 L
s
.30952 .48273 m
.30952 .48648 L
s
.35714 .48273 m
.35714 .48648 L
s
.45238 .48273 m
.45238 .48648 L
s
.5 .48273 m
.5 .48648 L
s
.54762 .48273 m
.54762 .48648 L
s
.64286 .48273 m
.64286 .48648 L
s
.69048 .48273 m
.69048 .48648 L
s
.7381 .48273 m
.7381 .48648 L
s
.83333 .48273 m
.83333 .48648 L
s
.88095 .48273 m
.88095 .48648 L
s
.92857 .48273 m
.92857 .48648 L
s
.25 Mabswid
0 .48273 m
1 .48273 L
s
.02381 .06565 m
.03006 .06565 L
s
[(-0.00005)] .01131 .06565 1 0 Mshowa
.02381 .14907 m
.03006 .14907 L
s
[(-0.00004)] .01131 .14907 1 0 Mshowa
.02381 .23248 m
.03006 .23248 L
s
[(-0.00003)] .01131 .23248 1 0 Mshowa
.02381 .3159 m
.03006 .3159 L
s
[(-0.00002)] .01131 .3159 1 0 Mshowa
.02381 .39931 m
.03006 .39931 L
s
[(-0.00001)] .01131 .39931 1 0 Mshowa
.02381 .56614 m
.03006 .56614 L
s
[(0.00001)] .01131 .56614 1 0 Mshowa
.125 Mabswid
.02381 .08234 m
.02756 .08234 L
s
.02381 .09902 m
.02756 .09902 L
s
.02381 .1157 m
.02756 .1157 L
s
.02381 .13239 m
.02756 .13239 L
s
.02381 .16575 m
.02756 .16575 L
s
.02381 .18243 m
.02756 .18243 L
s
.02381 .19912 m
.02756 .19912 L
s
.02381 .2158 m
.02756 .2158 L
s
.02381 .24917 m
.02756 .24917 L
s
.02381 .26585 m
.02756 .26585 L
s
.02381 .28253 m
.02756 .28253 L
s
.02381 .29921 m
.02756 .29921 L
s
.02381 .33258 m
.02756 .33258 L
s
.02381 .34926 m
.02756 .34926 L
s
.02381 .36595 m
.02756 .36595 L
s
.02381 .38263 m
.02756 .38263 L
s
.02381 .41599 m
.02756 .41599 L
s
.02381 .43268 m
.02756 .43268 L
s
.02381 .44936 m
.02756 .44936 L
s
.02381 .46604 m
.02756 .46604 L
s
.02381 .49941 m
.02756 .49941 L
s
.02381 .51609 m
.02756 .51609 L
s
.02381 .53277 m
.02756 .53277 L
s
.02381 .54946 m
.02756 .54946 L
s
.02381 .04897 m
.02756 .04897 L
s
.02381 .03229 m
.02756 .03229 L
s
.02381 .01561 m
.02756 .01561 L
s
.02381 .58282 m
.02756 .58282 L
s
.02381 .59951 m
.02756 .59951 L
s
.02381 .61619 m
.02756 .61619 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .29328 m
.03279 .21144 L
.04262 .1304 L
.04758 .09559 L
.05288 .06428 L
.05789 .04121 L
.06006 .03334 L
.06244 .02623 L
.06507 .02035 L
.0665 .018 L
.06719 .0171 L
.06785 .01637 L
.0691 .01534 L
.07025 .01482 L
.07148 .01472 L
.07218 .01486 L
.07283 .01513 L
.07354 .01557 L
.0743 .01622 L
.07569 .01786 L
.07704 .02001 L
.07829 .02247 L
.08112 .02979 L
.0841 .04004 L
.08915 .06296 L
.09387 .09022 L
.10458 .16952 L
.12322 .33828 L
.13305 .42533 L
.14349 .50312 L
.14873 .5336 L
.15152 .54698 L
.15452 .55907 L
.15727 .56789 L
.15847 .57107 L
.15979 .57405 L
.16095 .57625 L
.16219 .57816 L
.16351 .57966 L
.16473 .58059 L
.16539 .5809 L
.16608 .58108 L
.16733 .58104 L
.16802 .58081 L
.16867 .58046 L
.16939 .57992 L
.17015 .57918 L
.17152 .5774 L
.17283 .57519 L
.17527 .56966 L
Mistroke
.17765 .5626 L
.17985 .55461 L
.18485 .53159 L
.19544 .463 L
.20541 .38033 L
.22403 .21062 L
.23382 .13095 L
.23917 .09442 L
.24415 .06614 L
.24841 .04698 L
.25059 .03907 L
.25297 .03204 L
.25432 .02877 L
.25557 .02623 L
.25674 .02428 L
.25803 .02261 L
.25918 .02154 L
.26026 .02091 L
.2614 .02063 L
.26263 .02077 L
.2639 .02141 L
.26504 .0224 L
.26636 .02405 L
.26761 .02608 L
.26983 .03086 L
.27223 .03768 L
.27769 .05925 L
.28271 .0861 L
.29298 .15844 L
.30383 .25259 L
.32366 .43237 L
.33233 .49818 L
.3369 .52686 L
.34177 .5518 L
.34423 .56207 L
.34696 .57143 L
.34944 .57808 L
.35177 .58266 L
.35293 .58432 L
.35415 .58564 L
.35519 .58641 L
.35633 .58686 L
.35756 .58691 L
.35888 .58644 L
.36012 .58552 L
.36125 .58426 L
.36255 .58234 L
.36393 .57975 L
.36641 .57368 L
.36907 .56515 L
Mistroke
.372 .55346 L
.38216 .49591 L
.3923 .41733 L
.40158 .33444 L
.41241 .23495 L
.42247 .1505 L
.43166 .08798 L
.43681 .06147 L
.44147 .04353 L
.44414 .03603 L
.4466 .031 L
.44788 .02909 L
.44862 .02822 L
.44929 .02757 L
.45 .02703 L
.45077 .02663 L
.45147 .02642 L
.45214 .02635 L
.45336 .02659 L
.45464 .02734 L
.45574 .02838 L
.45696 .02995 L
.45826 .03213 L
.45966 .03505 L
.46219 .0418 L
.46716 .06038 L
.47177 .08362 L
.48225 .15463 L
.50335 .34231 L
.51246 .42393 L
.5221 .49903 L
.52714 .53113 L
.53268 .55939 L
.5351 .56921 L
.53771 .57791 L
.54017 .58431 L
.54242 .58858 L
.54374 .59038 L
.54447 .59115 L
.54514 .59171 L
.54644 .5924 L
.54766 .59259 L
.54836 .59248 L
.5491 .59222 L
.55041 .59132 L
.55115 .5906 L
.55183 .58977 L
.55338 .58737 L
.55601 .58166 L
.5584 .57469 L
Mistroke
.56378 .55313 L
.56875 .52646 L
.57414 .491 L
.58394 .41301 L
.60337 .23621 L
.61369 .15037 L
.61938 .11044 L
.62479 .07904 L
.62986 .05636 L
.63273 .04666 L
.63539 .0398 L
.63666 .03727 L
.63786 .03533 L
.63893 .03395 L
.64009 .03286 L
.64136 .03214 L
.642 .03196 L
.6427 .03191 L
.64394 .03218 L
.6451 .03287 L
.64628 .03399 L
.64756 .03569 L
.6499 .04006 L
.65218 .04588 L
.65428 .05261 L
.65906 .07248 L
.66413 .10013 L
.67349 .1662 L
.68359 .25295 L
.70187 .42022 L
.71224 .50217 L
.7173 .53478 L
.7219 .55916 L
.72677 .57889 L
.72945 .58687 L
.73197 .59248 L
.73331 .59467 L
.73404 .59563 L
.73472 .59639 L
.73593 .59739 L
.73657 .59773 L
.73726 .59796 L
.738 .59805 L
.7388 .59795 L
.73955 .59768 L
.74026 .59728 L
.74095 .59672 L
.74158 .5961 L
.743 .59425 L
.7442 .5922 L
Mistroke
.74533 .58989 L
.74788 .58325 L
.75037 .57496 L
.75304 .56416 L
.76227 .51263 L
.77317 .42908 L
.7831 .34022 L
.79316 .24783 L
.80383 .15833 L
.81294 .09708 L
.81812 .0708 L
.82045 .06133 L
.82299 .0527 L
.82542 .04619 L
.82769 .0417 L
.82894 .03989 L
.83008 .03865 L
.83139 .03771 L
.83263 .03731 L
.8337 .03734 L
.83484 .03776 L
.8358 .03843 L
.83687 .03949 L
.83801 .04102 L
.83924 .04311 L
.84146 .04801 L
.84402 .05546 L
.8468 .0657 L
.85186 .08974 L
.86136 .1514 L
.88071 .31968 L
.89099 .41375 L
.90209 .50307 L
.90723 .53682 L
.91264 .56569 L
.91725 .58422 L
.91987 .59204 L
.92231 .59752 L
.9235 .59953 L
.92478 .60124 L
.926 .60239 L
.92712 .60305 L
.92813 .60332 L
.92924 .60325 L
.93041 .60277 L
.93149 .60195 L
.93276 .60054 L
.93397 .59875 L
.93623 .5942 L
.93866 .58762 L
Mistroke
.94132 .57849 L
.94588 .55827 L
.95017 .53433 L
.9582 .47864 L
.97619 .32129 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<P3oool00`000000oooo0?oo
o`3[0?ooo`00<P3oool00`000000oooo0?ooo`3[0?ooo`00<P3oool00`000000oooo0?ooo`3[0?oo
o`00<P3oool00`000000oooo0?ooo`3[0?ooo`00<P3oool2000000T0oooo0`00003P0?ooo`00<P3o
ool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000003oool0:P3oool200000;<0oooo000b
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000:P3oool300000;<0oooo000b
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`8000000P3o
ool00`000000oooo0?ooo`0X0?ooo`800000QP3oool00380oooo0P0000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool0000002T0oooo00@0
00000?ooo`3oool00000:P3oool3000005P0oooo000b0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool09P3oool010000000oooo0?ooo`00000Z0?ooo`030000003oool0000002/0oooo
0P00000[0?ooo`00<P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000000
:@3oool4000002X0oooo000b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo
0000000Y0?ooo`040000003oool0oooo000002X0oooo000b0?ooo`8000001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool01@000000oooo
0?ooo`3oool0000002P0oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`00<P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool01@000000
oooo0?ooo`3oool0000002X0oooo00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000103oool2000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02L0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool09`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0V0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0V0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02H0oooo00080?ooo`8000002P3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000@0oooo0`0000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool09P3oool00380oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo000b0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool09@3oool00380oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0U0?ooo`00<P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02D0oooo000b0?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`00<P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo000b0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0903oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0T0?ooo`00<P3oool2000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0903oool00380oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`00<P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02@0oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0903oool00380oooo0P0000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo000b0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool08`3oool000P0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo0`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08`3oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0S0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo1@0000020?ooo`<0000000<0oooo0000003oool03@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00003
0?ooo`0000000000008000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0
000000h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000003`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool0
00P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool20000
00<0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`00<P3oool200000080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool08`3oool00380oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`00<P3oool01@000000
oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0280oooo000b0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00380
oooo0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo000b0?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool08P3oool00380oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool08P3oool00380oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool08P3oool00380oooo0P0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0R0?ooo`00<P3oool010000000oooo0?oo
o`00000A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0Q0?ooo`00<P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`00<P3oool010000000oooo0?oo
o`00000A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0Q0?ooo`00<P3oool2000000030?ooo`000000oooo0100oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0240oooo000b0?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0240oooo00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`001`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0000000B0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool3
00000180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0240oooo00000`3oool000000000000200000080oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000050?ooo`070000003oool0oooo0?ooo`000000oooo0000
000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0P0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000000C0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`00203oool2
000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool0
0`000000oooo0000000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0P0?ooo`00<P3oool3000001<0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0200oooo000b0?ooo`800000503oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool00380oooo
0P00000D0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0P0?ooo`00<P3oool2000001@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0200oooo000b0?ooo`800000503oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0803oool00380oooo0P00000D0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?oo
o`00<P3oool2000001@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01l0oooo000b0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo000b0?ooo`8000005@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3o
ool00380oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool07`3oool00380oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07`3oool00380
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool07`3oool00380oooo0P00000E0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?ooo`00<P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0N0?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000004
0?ooo`8000000`3oool4000000<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool07P3oool000L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo0`00000D0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N0?ooo`00
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`070?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo000b0?ooo`8000005P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`00<P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000b0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0203oool00380oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`080?ooo`00<P3oool2000001H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool00380oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`00<P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00P0oooo000b0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0203oool00380oooo0P00000G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo000b0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`090?ooo`00<P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00T0oooo000b0?ooo`800000603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00<P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00080?ooo`800000103oool2000000@0oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000030?ooo`D000000P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00T0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool02@3oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0`00000G0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00X0oooo00000`3oool000000000000200000080oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00080?ooo`8000002P3o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02P3oool00380oooo0P00000I0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00X0oooo000b0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00380
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`00<P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00/0oooo000b0?ooo`8000006@3oool00`000000oooo0?oo
o`060?ooo`800000103oool2000000@0oooo0P0000030?ooo`@000003`3oool00`000000oooo0?oo
o`060?ooo`800000103oool2000000@0oooo0P0000050?ooo`<000003P3oool00`000000oooo0?oo
o`070?ooo`800000103oool2000000@0oooo0P0000030?ooo`<000003`3oool00`000000oooo0?oo
o`070?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000403oool00`000000oooo0?oo
o`0:0?ooo`80000000@0oooo0000003oool0oooo0P0000030?ooo`D000000@3oool00380oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo008000002@3oool00`000000oooo0?ooo`010?ooo`00<P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`D000003`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000l0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02000000T0oooo00<00000
0?ooo`3oool00@3oool00380oooo0P00000J0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0100oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool300000100oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`3oool200000100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020000
00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000l0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02000000T0oooo00<000000?ooo`3o
ool00@3oool00380oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`800000
0`3oool00`000000oooo0?ooo`040?ooo`800000103oool200000140oooo00<000000?ooo`3oool0
1@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P00000@0?ooo`030000
003oool0oooo00H0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`<00000
3`3oool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
103oool200000100oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000oooo00L0oooo
0P0000030?ooo`00<P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo000b
0?ooo`8000006P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`00<P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo000b0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00380oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`00;@3o
ooo_000000@0oooo000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo000b0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3o
ool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo000b0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03@3oool00380oooo0P00000K0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00d0oooo000b0?ooo`8000006`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00380oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0>0?ooo`00<P3oool2000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00380oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00<P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo000b0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00380oooo0P00000M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo000b0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool000P0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo1@0000020?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03`3oool000L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool30000
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03`3oool000L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07@3oool2000000<0oooo00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool00000
02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0100oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3o
ool00000:@3oool01@000000oooo0?ooo`3oool0000002L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00080?ooo`8000002P3oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
01h0oooo00@000000?ooo`0000000000:@3oool01@000000oooo0?ooo`3oool0000002P0oooo00D0
00000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000b0?ooo`800000803o
ool2000002/0oooo00@000000?ooo`0000000000:03oool01@000000oooo0?ooo`3oool0000002P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool00380oooo00<000000?ooo`3oool0C03oool3000002X0oooo
00@000000?ooo`3oool00000:@3oool010000000oooo0?ooo`00000X0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0403oool00380oooo00<000000?ooo`3oool0N@3oool3000002X0
oooo00@000000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool0000001<0oooo000b0?oo
o`030000003oool0oooo07X0oooo0P00000Z0?ooo`80000000<0oooo0000003oool0:03oool01@00
0000oooo0?ooo`3oool0000001<0oooo000b0?ooo`800000Z03oool2000002/0oooo00<000000?oo
o`000000503oool00380oooo00<000000?ooo`3oool0e03oool3000001@0oooo000b0?ooo`030000
003oool0oooo0>/0oooo000b0?ooo`030000003oool0oooo0>/0oooo000b0?ooo`800000k03oool0
0380oooo00<000000?ooo`3oool0j`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0224566, -6.53189*^-05, \
0.000440493, 5.02933*^-07}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Dumped Vibration with Two Characteristic Values", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 2\ Sqrt[K\ M] - 1;\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Q*Sin[omg\ t], x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \[ExponentialE]\^\(\((\(-0.2440169358562924`\) - \
0.5232485722375546`\ \[ImaginaryI])\)\ t\)\ C[
                1] + \[ExponentialE]\^\(\((\(-0.2440169358562924`\) + \
0.5232485722375546`\ \[ImaginaryI])\)\ t\)\ C[
                2] - \((5.2466365176205215`*^-8 + 
                  0.`\ \[ImaginaryI])\)\ \[ExponentialE]\^\(0.`\ \
\[ImaginaryI]\ t\)\ Cos[
                314.1592653589793`\ t] - \((\(\(0.000033773760442955855`\)\(\
\[InvisibleSpace]\)\) + 
                  0.`\ \[ImaginaryI])\)\ \[ExponentialE]\^\(0.`\ \
\[ImaginaryI]\ t\)\ Sin[314.1592653589793`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(B = 2\ Sqrt[K\ M] - 1;\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Q*Sin[omg\ t], x[t], t, 
          GeneratedParameters \[Rule] Con] // Chop\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(-0.000022515801688411904`\)\ \
\[ExponentialE]\^\(\((\(-0.2440169358562924`\) - 0.5232485722375546`\ \
\[ImaginaryI])\)\ t\) - 5.2466365176205215`*^-8\ Cos[314.1592653589793`\ t] - 
            0.000033773760442955855`\ Sin[
                314.1592653589793`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Re[Evaluate[x[t] /. solution]], {t, 0, 0.1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381 0.501292 8648.44 [
[.21429 .48879 -12 -9 ]
[.21429 .48879 12 0 ]
[.40476 .48879 -12 -9 ]
[.40476 .48879 12 0 ]
[.59524 .48879 -12 -9 ]
[.59524 .48879 12 0 ]
[.78571 .48879 -12 -9 ]
[.78571 .48879 12 0 ]
[.97619 .48879 -9 -9 ]
[.97619 .48879 9 0 ]
[.01131 .06887 -48 -4.5 ]
[.01131 .06887 0 4.5 ]
[.01131 .15535 -48 -4.5 ]
[.01131 .15535 0 4.5 ]
[.01131 .24184 -48 -4.5 ]
[.01131 .24184 0 4.5 ]
[.01131 .32832 -48 -4.5 ]
[.01131 .32832 0 4.5 ]
[.01131 .41481 -48 -4.5 ]
[.01131 .41481 0 4.5 ]
[.01131 .58778 -42 -4.5 ]
[.01131 .58778 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .50129 m
.21429 .50754 L
s
[(0.02)] .21429 .48879 0 1 Mshowa
.40476 .50129 m
.40476 .50754 L
s
[(0.04)] .40476 .48879 0 1 Mshowa
.59524 .50129 m
.59524 .50754 L
s
[(0.06)] .59524 .48879 0 1 Mshowa
.78571 .50129 m
.78571 .50754 L
s
[(0.08)] .78571 .48879 0 1 Mshowa
.97619 .50129 m
.97619 .50754 L
s
[(0.1)] .97619 .48879 0 1 Mshowa
.125 Mabswid
.07143 .50129 m
.07143 .50504 L
s
.11905 .50129 m
.11905 .50504 L
s
.16667 .50129 m
.16667 .50504 L
s
.2619 .50129 m
.2619 .50504 L
s
.30952 .50129 m
.30952 .50504 L
s
.35714 .50129 m
.35714 .50504 L
s
.45238 .50129 m
.45238 .50504 L
s
.5 .50129 m
.5 .50504 L
s
.54762 .50129 m
.54762 .50504 L
s
.64286 .50129 m
.64286 .50504 L
s
.69048 .50129 m
.69048 .50504 L
s
.7381 .50129 m
.7381 .50504 L
s
.83333 .50129 m
.83333 .50504 L
s
.88095 .50129 m
.88095 .50504 L
s
.92857 .50129 m
.92857 .50504 L
s
.25 Mabswid
0 .50129 m
1 .50129 L
s
.02381 .06887 m
.03006 .06887 L
s
[(-0.00005)] .01131 .06887 1 0 Mshowa
.02381 .15535 m
.03006 .15535 L
s
[(-0.00004)] .01131 .15535 1 0 Mshowa
.02381 .24184 m
.03006 .24184 L
s
[(-0.00003)] .01131 .24184 1 0 Mshowa
.02381 .32832 m
.03006 .32832 L
s
[(-0.00002)] .01131 .32832 1 0 Mshowa
.02381 .41481 m
.03006 .41481 L
s
[(-0.00001)] .01131 .41481 1 0 Mshowa
.02381 .58778 m
.03006 .58778 L
s
[(0.00001)] .01131 .58778 1 0 Mshowa
.125 Mabswid
.02381 .08617 m
.02756 .08617 L
s
.02381 .10346 m
.02756 .10346 L
s
.02381 .12076 m
.02756 .12076 L
s
.02381 .13806 m
.02756 .13806 L
s
.02381 .17265 m
.02756 .17265 L
s
.02381 .18995 m
.02756 .18995 L
s
.02381 .20725 m
.02756 .20725 L
s
.02381 .22454 m
.02756 .22454 L
s
.02381 .25914 m
.02756 .25914 L
s
.02381 .27643 m
.02756 .27643 L
s
.02381 .29373 m
.02756 .29373 L
s
.02381 .31103 m
.02756 .31103 L
s
.02381 .34562 m
.02756 .34562 L
s
.02381 .36292 m
.02756 .36292 L
s
.02381 .38021 m
.02756 .38021 L
s
.02381 .39751 m
.02756 .39751 L
s
.02381 .4321 m
.02756 .4321 L
s
.02381 .4494 m
.02756 .4494 L
s
.02381 .4667 m
.02756 .4667 L
s
.02381 .484 m
.02756 .484 L
s
.02381 .51859 m
.02756 .51859 L
s
.02381 .53589 m
.02756 .53589 L
s
.02381 .55318 m
.02756 .55318 L
s
.02381 .57048 m
.02756 .57048 L
s
.02381 .05157 m
.02756 .05157 L
s
.02381 .03428 m
.02756 .03428 L
s
.02381 .01698 m
.02756 .01698 L
s
.02381 .60507 m
.02756 .60507 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30611 m
.03279 .22095 L
.04262 .13648 L
.04758 .10011 L
.05288 .06734 L
.05789 .0431 L
.06006 .0348 L
.06244 .02727 L
.06507 .021 L
.0665 .01847 L
.06719 .01748 L
.06785 .01668 L
.0691 .01553 L
.07025 .01491 L
.07148 .01472 L
.07218 .01482 L
.07283 .01505 L
.07354 .01546 L
.0743 .01608 L
.07569 .01768 L
.07704 .01982 L
.07829 .02229 L
.08112 .02969 L
.0841 .04013 L
.08915 .06357 L
.09387 .09155 L
.10458 .17321 L
.12322 .34755 L
.13305 .43765 L
.14349 .51827 L
.14873 .5499 L
.15152 .5638 L
.15452 .57636 L
.15727 .58554 L
.15847 .58884 L
.15979 .59195 L
.16095 .59425 L
.16219 .59624 L
.16351 .59782 L
.16473 .5988 L
.16539 .59913 L
.16608 .59932 L
.16733 .5993 L
.16802 .59907 L
.16867 .59871 L
.16939 .59817 L
.17015 .59741 L
.17152 .59559 L
.17283 .5933 L
.17527 .5876 L
Mistroke
.17765 .58031 L
.17985 .57205 L
.18485 .54823 L
.19544 .47714 L
.20541 .39133 L
.22403 .21485 L
.23382 .1318 L
.23917 .09364 L
.24415 .06402 L
.24841 .04389 L
.25059 .03555 L
.25297 .0281 L
.25432 .02462 L
.25557 .02191 L
.25674 .01981 L
.25803 .01798 L
.25918 .0168 L
.26026 .01607 L
.2614 .01571 L
.26263 .01578 L
.2639 .01635 L
.26504 .0173 L
.26636 .01892 L
.26761 .02095 L
.26983 .02575 L
.27223 .03266 L
.27769 .05469 L
.28271 .08222 L
.29298 .15667 L
.30383 .25385 L
.32366 .43984 L
.33233 .50805 L
.3369 .53781 L
.34177 .56371 L
.34423 .57438 L
.34696 .58412 L
.34944 .59104 L
.35177 .59582 L
.35293 .59757 L
.35415 .59895 L
.35519 .59976 L
.35633 .60025 L
.35756 .60031 L
.35888 .59985 L
.36012 .59891 L
.36125 .59763 L
.36255 .59565 L
.36393 .59298 L
.36641 .58672 L
.36907 .57791 L
Mistroke
.372 .56582 L
.38216 .50621 L
.3923 .42471 L
.40158 .33862 L
.41241 .23515 L
.42247 .14717 L
.43166 .08185 L
.43681 .05406 L
.44147 .03517 L
.44414 .02722 L
.4466 .02184 L
.44788 .01978 L
.44929 .01811 L
.45 .0175 L
.45077 .01704 L
.45149 .01676 L
.45214 .01666 L
.45343 .01685 L
.45462 .01749 L
.45592 .01871 L
.45658 .01954 L
.4573 .0206 L
.45983 .02557 L
.46219 .03202 L
.4669 .04978 L
.47204 .0763 L
.48239 .149 L
.5009 .31813 L
.51184 .42071 L
.52217 .50451 L
.52667 .53451 L
.53144 .56085 L
.53393 .57217 L
.53667 .58257 L
.53915 .5901 L
.54148 .59543 L
.54274 .5976 L
.5439 .59917 L
.54518 .60041 L
.54589 .60087 L
.54653 .60116 L
.54772 .60133 L
.549 .60101 L
.55022 .60024 L
.55133 .59911 L
.55241 .59765 L
.55342 .59595 L
.5557 .59093 L
.55793 .58449 L
.56032 .57595 L
Mistroke
.56576 .5504 L
.57091 .51909 L
.58055 .44508 L
.59882 .27464 L
.60921 .17925 L
.61895 .10343 L
.62384 .07287 L
.6285 .04952 L
.63107 .03924 L
.63387 .03022 L
.6351 .02701 L
.63641 .0241 L
.63756 .02199 L
.63878 .02021 L
.63945 .01942 L
.6402 .01872 L
.6415 .01791 L
.64224 .0177 L
.64303 .01766 L
.64377 .0178 L
.64445 .01809 L
.64577 .01906 L
.64651 .01984 L
.6472 .02073 L
.64854 .02289 L
.6498 .02542 L
.65211 .03133 L
.65465 .03971 L
.6598 .06244 L
.6645 .08936 L
.66963 .12483 L
.67998 .21121 L
.69848 .38668 L
.70856 .47455 L
.71808 .54112 L
.72334 .56857 L
.72612 .57994 L
.72905 .58952 L
.73152 .59556 L
.73293 .59815 L
.73424 .60001 L
.73545 .60125 L
.73655 .60197 L
.73782 .60233 L
.73903 .60219 L
.74028 .60156 L
.74098 .60099 L
.74162 .60032 L
.74281 .59876 L
.74407 .59663 L
Mistroke
.74625 .59177 L
.74863 .58477 L
.75393 .56326 L
.75886 .53626 L
.76775 .47319 L
.77726 .39042 L
.7971 .20299 L
.80756 .11754 L
.81329 .07984 L
.81866 .05192 L
.82341 .03398 L
.82607 .02685 L
.82726 .02439 L
.82852 .02224 L
.82983 .02054 L
.83105 .01944 L
.8318 .01901 L
.8325 .01875 L
.83382 .01871 L
.83449 .0189 L
.83521 .01926 L
.83649 .02031 L
.8372 .02112 L
.83787 .02202 L
.83939 .02459 L
.84187 .03033 L
.84422 .03751 L
.84863 .05536 L
.85338 .08059 L
.85855 .11446 L
.8779 .28206 L
.88818 .3805 L
.89928 .47753 L
.90442 .51563 L
.90983 .54943 L
.91444 .57233 L
.91709 .58277 L
.9195 .59046 L
.92067 .59357 L
.92195 .59647 L
.92305 .59857 L
.92426 .60044 L
.92554 .60192 L
.92624 .60251 L
.9269 .60293 L
.92808 .60332 L
.92934 .60325 L
.93051 .60273 L
.93179 .60167 L
.933 .60019 L
Mistroke
.93413 .59841 L
.93625 .59397 L
.93851 .58772 L
.94336 .56914 L
.94783 .54621 L
.95791 .47668 L
.97619 .31107 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<P3oool00`000000oooo0?oo
o`3[0?ooo`00<P3oool00`000000oooo0?ooo`3[0?ooo`00<P3oool00`000000oooo0?ooo`3[0?oo
o`00<P3oool00`000000oooo0?ooo`3[0?ooo`00<P3oool2000000T0oooo0`00000[0?ooo`800000
:`3oool2000008H0oooo000b0?ooo`030000003oool0oooo00L0oooo0P0000000`3oool000000?oo
o`0Y0?ooo`040000003oool00000000002X0oooo0`00000Z0?ooo`<00000:`3oool2000002/0oooo
000b0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000:@3oool200000080oooo
00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00000Z0?ooo`040000003oool000000000
02T0oooo00@000000?ooo`3oool00000:P3oool00380oooo00<000000?ooo`3oool01`3oool01@00
0000oooo0?ooo`3oool0000002P0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`040000003o
ool0oooo000002T0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`040000003oool0oooo0000
02X0oooo000b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo0000000X0?oo
o`050000003oool0oooo0?ooo`000000:P3oool00380oooo0P0000070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02L0oooo000b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00380oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`00<P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02H0oooo000b0?ooo`8000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V
0?ooo`00<P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo00080?ooo`80
0000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo00070?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000
003oool0oooo0?ooo`<00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`0000<0oooo000000000000
0P0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo0008
0?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0`000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09@3oool00380oooo0P0000040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02D0oooo000b0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool09@3oool00380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`00<P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo000b0?ooo`800000103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0T0?ooo`00<P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02@0oooo000b0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00380oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`00<P3oool2000000<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0903oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T
0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo000b0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00380oooo0P0000030?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02<0oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3o
ool000P0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2
000000D0oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`001`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo1@0000020?oo
o`<000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`0000<0oooo0000000000000P0000020?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`00203oool2000000X0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000050?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
000000l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02<0oooo000b0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00380oooo0P0000020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0280oooo000b0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00380
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0R0?ooo`00<P3oool01@000000oooo0?ooo`3oool00000
00l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0280oooo000b0?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0R0?ooo`00<P3oool01@000000oooo
0?ooo`3oool0000000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0280oooo000b0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo000b0?ooo`040000
003oool0oooo00000140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0240oooo000b0?ooo`80000000<0oooo0000003oool0403oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3oool00380oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool08@3oool00380oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3oool00380oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool08@3oool00380oooo0P0000000`3oool000000?ooo`0@0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`00<P3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0Q0?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000004P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo0`00000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0P0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000004`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0803oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000004`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803o
ool000P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0803oool00380oooo0`00000C0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`00<P3oool2000001@0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200
oooo000b0?ooo`800000503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0803oool00380oooo0P00000D0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`00<P3oool2000001@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo000b0?oo
o`800000503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool07`3oool00380oooo0P00000E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0O0?ooo`00<P3oool2000001D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo000b0?ooo`8000005@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3o
ool00380oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool07`3oool00380oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool00380
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool07P3oool00380oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool00380oooo0P00
000E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00L0oooo000b0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?oo
o`800000103oool2000000<0oooo100000030?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`070?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00`3oool3000001D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool000030?ooo`0000000000008000000P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00P0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0203oool000P0oooo0P00000:0?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`080?ooo`00<P3oool2000001H0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool00380
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`00<P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00P0oooo000b0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0203oool00380oooo0P00000G0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo000b0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`090?ooo`00<P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00T0oooo000b0?ooo`8000005`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`00<P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo000b0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`090?ooo`00<P3oool2000001P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00380oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`00203oool2000000@0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3oool500000080oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00070?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`<0
00005`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0:0?ooo`0000<0oooo0000000000000P0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool000L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00203oool2
000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo000b0?ooo`8000006@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0;0?ooo`00<P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0
oooo000b0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00380oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`00<P3oool2000001T0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02`3oool00380oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?oo
o`00<P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`80
0000103oool2000000<0oooo1000000?0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`80
0000103oool2000000D0oooo0`00000?0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`80
0000103oool2000000<0oooo0`00000@0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`80
0000103oool2000000@0oooo0P00000A0?ooo`030000003oool0oooo00T0oooo0P000000103oool0
00000?ooo`3oool2000000<0oooo1@0000010?ooo`00<P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000@0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo008000002@3oool00`000000
oooo0?ooo`010?ooo`00<P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`D000003`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000100oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`010?ooo`00<P3oool2000001X0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`<000004@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`8000004@3oool00`000000oooo0?oo
o`080?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00@3oool00380oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0100oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000000@0?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0203oool010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo0040oooo000b0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool0103oool2000000@0oooo0P00
000A0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P00
00050?ooo`800000403oool00`000000oooo0?ooo`060?ooo`8000000`3oool00`000000oooo0?oo
o`040?ooo`800000103oool300000100oooo00<000000?ooo`3oool01@3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0P00000A0?ooo`030000003oool0oooo00T0oooo0`00
00090?ooo`8000000`3oool00380oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`00<P3oool2000001X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00380oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`00<P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo000b0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3o
ool002d0ooook`0000040?ooo`00<P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`00<P3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03@3oool00380oooo0P00000K0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo000b
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00h0oooo000b0?ooo`800000703oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00<P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo000b0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03P3oool00380oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0>0?ooo`00<P3oool2000001`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00380oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00<P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00l0oooo000b0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03`3oool00380oooo0P00000M0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo000b0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool000P0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo1@0000020?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0403oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00D0
00000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0@0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool3000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000000
:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
403oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool010000000oooo0?oo
o`00000Y0?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000oooo0?ooo`3oool00000
02T0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000003oool0oooo0?ooo`0000004`3o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`00
000Z0?ooo`040000003oool00000000002T0oooo00@000000?ooo`3oool00000:@3oool010000000
oooo0?ooo`00000Y0?ooo`050000003oool0oooo0?ooo`0000004`3oool000P0oooo0P00000:0?oo
o`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?oo
o`3oool07`3oool2000002/0oooo0`00000Z0?ooo`<00000:`3oool00`000000oooo0000000Z0?oo
o`030000003oool0000001@0oooo000b0?ooo`030000003oool0oooo07X0oooo0P00000[0?ooo`80
0000:`3oool3000001@0oooo000b0?ooo`800000k03oool00380oooo00<000000?ooo`3oool0j`3o
ool00380oooo00<000000?ooo`3oool0j`3oool00380oooo00<000000?ooo`3oool0j`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0224566, -6.51469*^-05, \
0.000440493, 4.85078*^-07}}]
}, Closed]],

Cell[BoxData[
    \(\(Quit[];\)\)], "Input"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{665, 622},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 98, 4, 52, "Subsection"],

Cell[CellGroupData[{
Cell[1899, 61, 103, 2, 45, "Subsubsection"],
Cell[2005, 65, 31, 0, 29, "Text"],
Cell[2039, 67, 93, 1, 50, "Input"],
Cell[2135, 70, 33, 0, 29, "Text"],
Cell[2171, 72, 89, 1, 50, "Input"],
Cell[2263, 75, 27, 0, 29, "Text"],
Cell[2293, 77, 107, 2, 50, "Input"],
Cell[2403, 81, 46, 0, 29, "Text"],
Cell[2452, 83, 81, 1, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2570, 89, 44, 0, 45, "Subsubsection"],
Cell[2617, 91, 37, 0, 29, "Text"],
Cell[2657, 93, 146, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2840, 101, 59, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[2924, 105, 124, 3, 50, "Input"],
Cell[3051, 110, 400, 8, 116, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3500, 124, 39, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[3564, 128, 182, 4, 70, "Input"],
Cell[3749, 134, 410, 6, 184, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4196, 145, 596, 12, 230, "Input"],
Cell[4795, 159, 546, 10, 68, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[5378, 174, 87, 1, 50, "Input"],
Cell[5468, 177, 56623, 1112, 186, 7503, 501, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[62140, 1295, 70, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[62235, 1299, 165, 3, 70, "Input"],
Cell[62403, 1304, 953, 16, 129, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[63393, 1325, 299, 6, 130, "Input"],
Cell[63695, 1333, 960, 17, 129, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[64692, 1355, 83, 1, 50, "Input"],
Cell[64778, 1358, 55752, 1111, 186, 7604, 512, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[120579, 2475, 73, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[120677, 2479, 165, 3, 70, "Input"],
Cell[120845, 2484, 640, 12, 74, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[121522, 2501, 309, 6, 130, "Input"],
Cell[121834, 2509, 329, 6, 73, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[122200, 2520, 87, 1, 50, "Input"],
Cell[122290, 2523, 56894, 1121, 186, 7572, 508, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[179199, 3647, 44, 1, 50, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

