(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17066,        655]*)
(*NotebookOutlinePosition[     23772,        848]*)
(*  CellTagsIndexPosition[     23697,        842]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Note-12"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Definite and Indefinite integrals", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x^2, x]\)], "Input"],

Cell[BoxData[
    \(2\ x\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x^2 + c, x]\)], "Input"],

Cell[BoxData[
    \(2\ x\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Indefinite integrals", "Subsubsection",
  CellTags->"Integrate"],

Cell["\<\
Here are three indefinite integrals that are evaluated by the (extended) \
Risch algorithm. \
\>", "ExampleText",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\(x\^n\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(x\^\(1 + n\)\/\(1 + n\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]Exp[a\ x\^2] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(\@\[Pi]\ Erfi[\@a\ x]\)\/\(2\ \@a\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\(\@\(a + b\ Cos[c\ x]\)\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(2\ \@\(a + b\ Cos[c\ x]\)\ EllipticE[\(c\ x\)\/2, \(2\ b\)\/\(a + \
b\)]\)\/\(c\ \@\(\(a + b\ Cos[c\ x]\)\/\(a + b\)\)\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell["\<\
Here are two indefinite integrals that are evaluated by special table lookup \
rules. \
\>", "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\(x\^n\ a\^x\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(-x\^\(1 + n\)\)\ Gamma[
        1 + n, \(-x\)\ Log[
            a]]\ \((\(-x\)\ Log[a])\)\^\(\(-1\) - n\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]MeijerG[{{}, {}}, {{a1, a2, a3}, {}}, 
          x] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(MeijerG[{{1}, {}}, {{1 + a1, 1 + a2, 1 + a3}, {0}}, x]\)], "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Definite integrals", "Subsubsection",
  CellTags->"Integrate"],

Cell["Here are some definite integrals. ", "ExampleText",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1\( 
            x\/\@\(1 + x\^2 - x\^4\)\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(ArcCot[2]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_\(\(-1\) - 1\ \[ImaginaryI]\)\%\(2 + 2\ \
\[ImaginaryI]\)\(x\ \ Abs[x]\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(14\ \[ImaginaryI]\ \@2\)\/3\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\( 
            1\/\(1 + x\^\[Pi]\)\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(Csc[1]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1\( Sin[
              x]\/\@\(1 - x\^2\)\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(1\/2\ \[Pi]\ StruveH[0, 1]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_\(-\(\(3\ \[Pi]\)\/2\)\)\%\(\(3\ \[Pi]\)\/2\)Min[Sin[x], 
            Cos[x]] \[DifferentialD]x // RootReduce\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(1\/2\ \((\(-2\) - 5\ \@2 - 2\ Sin[2\ ArcTan[1 + \@2]])\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_1\%\[Infinity] \[ExponentialE]\^\(-x\)\/\@\(x\^2 - 1\)\ \
\[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(BesselK[0, 1]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\(\( 
              x\ BesselJ[0, 
                x]\)\/\((x\^2 + 1)\)\^\(3\/2\)\) \[DifferentialD]x\)], "Input",\

  CellTags->"Integrate"],

Cell[BoxData[
    \(1\/\[ExponentialE]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1\(\( Log[1 - x]\ Log[
                1 - x\^2]\)\/x\^2\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(1\/4\ \((\[Pi]\^2 - 4\ Log[2]\^2)\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%\[Pi]\( Cos[x]\^\(3\/2\)\) \[DifferentialD]x\)], "Input",\

  CellTags->"Integrate"],

Cell[BoxData[
    \(\(2\ EllipticK[2]\)\/3\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1\( PolyLog[2, 
              x]\/\((1 + x)\)\^5\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(1\/384\ \((\(-22\) + 7\ \[Pi]\^2 - 64\ Log[2] + 
          48\ Log[2]\^2)\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1\( \[ExponentialE]\^\(-x\^3\)\) \(\@\(1 - 
              x\^3\)\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(\@\[Pi]\ Gamma[1\/3]\ Hypergeometric1F1[1\/3, 11\/6, \(-1\)]\)\/\(6\ \
Gamma[11\/6]\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1 BesselJ[1, x] 
        BesselK[1, x] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(MeijerG[{{1}, {}}, {{1\/4, 3\/4, 3\/4}, {\(-\(1\/4\)\), 0}}, \
1\/64]\/\(4\ \@\(2\ \[Pi]\)\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Options: ",
  StyleBox["Assumptions", "MR"],
  " and ",
  StyleBox["GenerateConditions", "MR"]
}], "Subsubsection",
  CellTags->"Integrate"],

Cell[TextData[{
  "When an integrand depends on a parameter, the indefinite integral should \
be considered valid for \
\[OpenCurlyDoubleQuote]generic\[CloseCurlyDoubleQuote] values of the \
parameter. For certain values the reported integral may be meaningless, as is \
the case here for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)], "InlineFormula"],
  ". "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]Exp[a\ x] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\[ExponentialE]\^\(a\ x\)\/a\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[TextData[{
  "By contrast, when you ask for a definite integral, ",
  StyleBox["Mathematica", "TI"],
  " tries to return a result that is always valid, if necessary by stating \
validity conditions. "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] Exp[a\ x] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(If[Re[a] < 0, \(-\(1\/a\)\), 
      Integrate[\[ExponentialE]\^\(a\ x\), {x, 0, \[Infinity]}, 
        Assumptions \[Rule] Re[a] \[GreaterEqual] 0]]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[TextData[{
  "The option ",
  StyleBox["Assumptions", "MR"],
  " lets you explicitly state conditions on the parameters. If you are only \
interested in real values of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)], "InlineFormula"],
  " that are less than 0, the reported result is unconditional. "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Exp[a\ x], {x, 0, \[Infinity]}, 
      Assumptions \[Rule] a < 0]\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(-\(1\/a\)\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[TextData[{
  "The same unconditional result is returned if you override the default \
setting of the option ",
  StyleBox["GenerateConditions", "MR"],
  ". Unless you know beforehand under what conditions the result is valid, \
this usage can lead to nonsense. "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Exp[a\ x], {x, 0, \[Infinity]}, 
      GenerateConditions \[Rule] False]\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(-\(1\/a\)\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[TextData[{
  "This integral is a definition of the ",
  StyleBox["Beta", "MR"],
  " function. "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[\(t\^\(a - 1\)\) \((1 - t)\)\^\(b - 1\), {t, 0, 1}, 
          Assumptions \[Rule] {Re[a] > 0, Re[b] > 0}] == Beta[a, b] // 
      FunctionExpand\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[TextData[{
  "Here is a more complicated example. For ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)], "InlineFormula"],
  ", the reported indefinite integral is not valid; the true integral is ",
  StyleBox["Log[x]", "MR"],
  ", since the integrand reduces to ",
  Cell[BoxData[
      \(TraditionalForm\`1/x\)], "InlineFormula"],
  ". "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(integral = \[Integral]\(BesselJ[0, 
                a\ x]\/x\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ MeijerG[{{}, {1}}, {{0, 
            0}, {0}}, \(a\^2\ x\^2\)\/4]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(integral /. a \[Rule] 0 // FullSimplify\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    RowBox[{\(FullSimplify::"infd"\), \(\(:\)\(\ \)\), \
"\<\"\:5f0f\\!\\(\\(\\(-\\(\\(1\\/2\\)\\)\\)\\)\\\\ \
\\(\\(MeijerG[\\(\\(\\(\\({\\(\\({}\\)\\), \\(\\({1}\\)\\)}\\)\\), \\(\\({\\(\
\\({0, 0}\\)\\), \\(\\({0}\\)\\)}\\)\\), 0\\)\\)]\\)\\)\\)\:306f\\!\\(-\
\[Infinity]\\)\:306b\:7c21\:7d04\:3055\:308c\:307e\:3057\:305f\:ff0e \
\\!\\(\\*ButtonBox[\\\"\:8a73\:7d30\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FullSimplify::infd\\\"]\\)\"\>"}]], "Message",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\(-\[Infinity]\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell["Here is the result when you ask for a definite integral. ", "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_a\%\[Infinity]\( BesselJ[0, 
              a\ x]\/x\) \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(If[a > 0, \(-EulerGamma\) + 
        1\/8\ a\^4\ HypergeometricPFQ[{1, 1}, {2, 2, 2}, \(-\(a\^4\/4\)\)] + 
        Log[2] - 2\ Log[a], 
      Integrate[BesselJ[0, a\ x]\/x, {x, a, \[Infinity]}, 
        Assumptions \[Rule] a \[LessEqual] 0]]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[TextData[{
  "Even for a definite integral, you should use results with caution if they \
depend on a parameter. In this example, the result is not valid if ",
  Cell[BoxData[
      \(TraditionalForm\`a\)], "InlineFormula"],
  " is such that there is a singularity in the segment ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \(\(\[InvisibleSpace]\)\([0, 1]\)\)\)], 
    "InlineFormula"],
  " (that is, if ",
  Cell[BoxData[
      \(TraditionalForm\`a\)], "InlineFormula"],
  " is real and at least ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/2\)], "InlineFormula"],
  "). "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Tan[a\ x], {x, 0, 1}]\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(If[\(-\(\[Pi]\/2\)\) \[LessEqual] Re[a] \[LessEqual] \[Pi]\/2 || 
        Im[a] \[NotEqual] 0, \(-\(Log[Cos[a]]\/a\)\), 
      Integrate[Tan[a\ x], {x, 0, 1}, 
        Assumptions \[Rule] \(! \((\(-\(\[Pi]\/2\)\) \[LessEqual] 
                  Re[a] \[LessEqual] \[Pi]\/2 || 
                Im[a] \[NotEqual] 0)\)\)]]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1 Tan[\(\[Pi]\ x\)\/2] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    RowBox[{\(Integrate::"idiv"\), \(\(:\)\(\ \)\), "\<\"\\!\\(Tan[\\(\\(\\(\
\[Pi]\\\\ x\\)\\/2\\)\\)]\\)\:306e\:7a4d\:5206\:306f\\!\\({0, 1}\\)\:3067\
\:53ce\:675f\:3057\:307e\:305b\:3093\:ff0e \
\\!\\(\\*ButtonBox[\\\"\:8a73\:7d30\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Integrate::idiv\\\"]\\)\"\>"}]], "Message",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\[Integral]\_0\%1 Tan[\(\[Pi]\ x\)\/2] \[DifferentialD]x\)], "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Options: ",
  StyleBox["PrincipalValue", "MR"]
}], "Subsubsection",
  CellTags->"Integrate"],

Cell[TextData[{
  "Sometimes an integrand has a singularity on the path of integration that \
causes the integral (in the Riemann sense of an area) to diverge. This is the \
case for this function, at the point ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)], "InlineFormula"],
  ". "
}], "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[x\^2\/\(x\^2 - 1\), {x, 0, \@3}]\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    RowBox[{\(Integrate::"idiv"\), \(\(:\)\(\ \)\), "\<\"\\!\\(x\\^2\\/\\(\\(\
\\(-1\\)\\) + x\\^2\\)\\)\:306e\:7a4d\:5206\:306f\\!\\({0, \\@3}\\)\:3067\
\:53ce\:675f\:3057\:307e\:305b\:3093\:ff0e \
\\!\\(\\*ButtonBox[\\\"\:8a73\:7d30\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Integrate::idiv\\\"]\\)\"\>"}]], "Message",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\[Integral]\_0\%\(\@3\)\(x\^2\/\(\(-1\) + 
              x\^2\)\) \[DifferentialD]x\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell["\<\
The integral may nonetheless exist in the sense of the Cauchy principal \
value. This value is defined by considering the integral obtained by omitting \
a small interval centered at the singularity, and taking the limit as the \
interval's length shrinks to zero. \
\>", "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{

Cell[BoxData[
    \(int = 
      Integrate[x\^2\/\(x\^2 - 1\), {x, 0, \@3}, 
        PrincipalValue -> True]\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(1\/2\ \((2\ \@3 + Log[\(-1\) + \@3] - Log[1 + \@3])\)\)], "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical integration", "Subsubsection",
  CellTags->"Integrate"],

Cell[TextData[{
  "When a function cannot be integrated symbolically, you can usually obtain \
a definite integral numerically using ",
  StyleBox["NIntegrate", "MR"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1 Sin[Sin[x]] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(\[Integral]\_0\%1 Sin[Sin[x]] \[DifferentialD]x\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[Sin[Sin[x]], {x, 0, 1}]\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(0.4306061031206906`\)], "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{712, 646},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Integrate"->{
    Cell[2238, 84, 70, 1, 45, "Subsubsection",
      CellTags->"Integrate"],
    Cell[2311, 87, 148, 4, 25, "ExampleText",
      CellTags->"Integrate"],
    Cell[2484, 95, 95, 2, 61, "Input",
      CellTags->"Integrate"],
    Cell[2582, 99, 82, 2, 65, "Output",
      CellTags->"Integrate"],
    Cell[2701, 106, 99, 2, 61, "Input",
      CellTags->"Integrate"],
    Cell[2803, 110, 96, 2, 73, "Output",
      CellTags->"Integrate"],
    Cell[2936, 117, 113, 2, 61, "Input",
      CellTags->"Integrate"],
    Cell[3052, 121, 181, 3, 99, "Output",
      CellTags->"Integrate"],
    Cell[3248, 127, 135, 4, 29, "Text",
      CellTags->"Integrate"],
    Cell[3408, 135, 101, 2, 61, "Input",
      CellTags->"Integrate"],
    Cell[3512, 139, 166, 4, 49, "Output",
      CellTags->"Integrate"],
    Cell[3715, 148, 138, 3, 61, "Input",
      CellTags->"Integrate"],
    Cell[3856, 153, 113, 2, 49, "Output",
      CellTags->"Integrate"],
    Cell[4018, 161, 68, 1, 45, "Subsubsection",
      CellTags->"Integrate"],
    Cell[4089, 164, 82, 1, 25, "ExampleText",
      CellTags->"Integrate"],
    Cell[4196, 169, 135, 3, 68, "Input",
      CellTags->"Integrate"],
    Cell[4334, 174, 68, 2, 49, "Output",
      CellTags->"Integrate"],
    Cell[4439, 181, 161, 3, 64, "Input",
      CellTags->"Integrate"],
    Cell[4603, 186, 88, 2, 67, "Output",
      CellTags->"Integrate"],
    Cell[4728, 193, 140, 3, 62, "Input",
      CellTags->"Integrate"],
    Cell[4871, 198, 65, 2, 49, "Output",
      CellTags->"Integrate"],
    Cell[4973, 205, 135, 3, 68, "Input",
      CellTags->"Integrate"],
    Cell[5111, 210, 85, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[5233, 217, 180, 3, 72, "Input",
      CellTags->"Integrate"],
    Cell[5416, 222, 115, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[5568, 229, 146, 3, 69, "Input",
      CellTags->"Integrate"],
    Cell[5717, 234, 72, 2, 49, "Output",
      CellTags->"Integrate"],
    Cell[5826, 241, 188, 5, 78, "Input",
      CellTags->"Integrate"],
    Cell[6017, 248, 77, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[6131, 255, 150, 3, 65, "Input",
      CellTags->"Integrate"],
    Cell[6284, 260, 94, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[6415, 267, 120, 3, 63, "Input",
      CellTags->"Integrate"],
    Cell[6538, 272, 81, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[6656, 279, 142, 3, 64, "Input",
      CellTags->"Integrate"],
    Cell[6801, 284, 134, 3, 62, "Output",
      CellTags->"Integrate"],
    Cell[6972, 292, 158, 3, 62, "Input",
      CellTags->"Integrate"],
    Cell[7133, 297, 146, 3, 81, "Output",
      CellTags->"Integrate"],
    Cell[7316, 305, 130, 3, 62, "Input",
      CellTags->"Integrate"],
    Cell[7449, 310, 151, 3, 74, "Output",
      CellTags->"Integrate"],
    Cell[7649, 319, 159, 6, 46, "Subsubsection",
      CellTags->"Integrate"],
    Cell[7811, 327, 404, 10, 48, "Text",
      CellTags->"Integrate"],
    Cell[8240, 341, 96, 2, 61, "Input",
      CellTags->"Integrate"],
    Cell[8339, 345, 87, 2, 63, "Output",
      CellTags->"Integrate"],
    Cell[8441, 350, 242, 6, 48, "Text",
      CellTags->"Integrate"],
    Cell[8708, 360, 113, 2, 61, "Input",
      CellTags->"Integrate"],
    Cell[8824, 364, 207, 4, 62, "Output",
      CellTags->"Integrate"],
    Cell[9046, 371, 343, 9, 48, "Text",
      CellTags->"Integrate"],
    Cell[9414, 384, 133, 3, 50, "Input",
      CellTags->"Integrate"],
    Cell[9550, 389, 72, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[9637, 394, 304, 7, 48, "Text",
      CellTags->"Integrate"],
    Cell[9966, 405, 140, 3, 50, "Input",
      CellTags->"Integrate"],
    Cell[10109, 410, 72, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[10196, 415, 137, 5, 29, "Text",
      CellTags->"Integrate"],
    Cell[10358, 424, 213, 4, 71, "Input",
      CellTags->"Integrate"],
    Cell[10574, 430, 63, 2, 49, "Output",
      CellTags->"Integrate"],
    Cell[10652, 435, 384, 11, 48, "Text",
      CellTags->"Integrate"],
    Cell[11061, 450, 138, 3, 62, "Input",
      CellTags->"Integrate"],
    Cell[11202, 455, 139, 3, 65, "Output",
      CellTags->"Integrate"],
    Cell[11378, 463, 97, 2, 50, "Input",
      CellTags->"Integrate"],
    Cell[11478, 467, 538, 9, 38, "Message",
      CellTags->"Integrate"],
    Cell[12019, 478, 75, 2, 49, "Output",
      CellTags->"Integrate"],
    Cell[12109, 483, 98, 1, 29, "Text",
      CellTags->"Integrate"],
    Cell[12232, 488, 142, 3, 62, "Input",
      CellTags->"Integrate"],
    Cell[12377, 493, 300, 6, 124, "Output",
      CellTags->"Integrate"],
    Cell[12692, 502, 633, 17, 48, "Text",
      CellTags->"Integrate"],
    Cell[13350, 523, 89, 2, 50, "Input",
      CellTags->"Integrate"],
    Cell[13442, 527, 378, 7, 94, "Output",
      CellTags->"Integrate"],
    Cell[13857, 539, 114, 2, 62, "Input",
      CellTags->"Integrate"],
    Cell[13974, 543, 399, 7, 36, "Message",
      CellTags->"Integrate"],
    Cell[14376, 552, 115, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[14540, 560, 111, 4, 46, "Subsubsection",
      CellTags->"Integrate"],
    Cell[14654, 566, 326, 8, 48, "Text",
      CellTags->"Integrate"],
    Cell[15005, 578, 100, 2, 65, "Input",
      CellTags->"Integrate"],
    Cell[15108, 582, 400, 7, 41, "Message",
      CellTags->"Integrate"],
    Cell[15511, 591, 142, 3, 68, "Output",
      CellTags->"Integrate"],
    Cell[15668, 597, 314, 6, 48, "Text",
      CellTags->"Integrate"],
    Cell[16007, 607, 146, 4, 65, "Input",
      CellTags->"Integrate"],
    Cell[16156, 613, 112, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[16317, 621, 71, 1, 45, "Subsubsection",
      CellTags->"Integrate"],
    Cell[16602, 633, 105, 2, 62, "Input",
      CellTags->"Integrate"],
    Cell[16710, 637, 106, 2, 62, "Output",
      CellTags->"Integrate"],
    Cell[16853, 644, 92, 2, 50, "Input",
      CellTags->"Integrate"],
    Cell[16948, 648, 78, 2, 49, "Output",
      CellTags->"Integrate"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Integrate", 17695, 671}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 98, 4, 52, "Subsection"],

Cell[CellGroupData[{
Cell[1899, 61, 58, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[1982, 65, 42, 1, 50, "Input"],
Cell[2027, 68, 38, 1, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2102, 74, 46, 1, 50, "Input"],
Cell[2151, 77, 38, 1, 49, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2238, 84, 70, 1, 45, "Subsubsection",
  CellTags->"Integrate"],
Cell[2311, 87, 148, 4, 25, "ExampleText",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[2484, 95, 95, 2, 61, "Input",
  CellTags->"Integrate"],
Cell[2582, 99, 82, 2, 65, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[2701, 106, 99, 2, 61, "Input",
  CellTags->"Integrate"],
Cell[2803, 110, 96, 2, 73, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[2936, 117, 113, 2, 61, "Input",
  CellTags->"Integrate"],
Cell[3052, 121, 181, 3, 99, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[3248, 127, 135, 4, 29, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[3408, 135, 101, 2, 61, "Input",
  CellTags->"Integrate"],
Cell[3512, 139, 166, 4, 49, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[3715, 148, 138, 3, 61, "Input",
  CellTags->"Integrate"],
Cell[3856, 153, 113, 2, 49, "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4018, 161, 68, 1, 45, "Subsubsection",
  CellTags->"Integrate"],
Cell[4089, 164, 82, 1, 25, "ExampleText",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[4196, 169, 135, 3, 68, "Input",
  CellTags->"Integrate"],
Cell[4334, 174, 68, 2, 49, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[4439, 181, 161, 3, 64, "Input",
  CellTags->"Integrate"],
Cell[4603, 186, 88, 2, 67, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[4728, 193, 140, 3, 62, "Input",
  CellTags->"Integrate"],
Cell[4871, 198, 65, 2, 49, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[4973, 205, 135, 3, 68, "Input",
  CellTags->"Integrate"],
Cell[5111, 210, 85, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[5233, 217, 180, 3, 72, "Input",
  CellTags->"Integrate"],
Cell[5416, 222, 115, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[5568, 229, 146, 3, 69, "Input",
  CellTags->"Integrate"],
Cell[5717, 234, 72, 2, 49, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[5826, 241, 188, 5, 78, "Input",
  CellTags->"Integrate"],
Cell[6017, 248, 77, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[6131, 255, 150, 3, 65, "Input",
  CellTags->"Integrate"],
Cell[6284, 260, 94, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[6415, 267, 120, 3, 63, "Input",
  CellTags->"Integrate"],
Cell[6538, 272, 81, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[6656, 279, 142, 3, 64, "Input",
  CellTags->"Integrate"],
Cell[6801, 284, 134, 3, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[6972, 292, 158, 3, 62, "Input",
  CellTags->"Integrate"],
Cell[7133, 297, 146, 3, 81, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[7316, 305, 130, 3, 62, "Input",
  CellTags->"Integrate"],
Cell[7449, 310, 151, 3, 74, "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7649, 319, 159, 6, 46, "Subsubsection",
  CellTags->"Integrate"],
Cell[7811, 327, 404, 10, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[8240, 341, 96, 2, 61, "Input",
  CellTags->"Integrate"],
Cell[8339, 345, 87, 2, 63, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[8441, 350, 242, 6, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[8708, 360, 113, 2, 61, "Input",
  CellTags->"Integrate"],
Cell[8824, 364, 207, 4, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[9046, 371, 343, 9, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[9414, 384, 133, 3, 50, "Input",
  CellTags->"Integrate"],
Cell[9550, 389, 72, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[9637, 394, 304, 7, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[9966, 405, 140, 3, 50, "Input",
  CellTags->"Integrate"],
Cell[10109, 410, 72, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[10196, 415, 137, 5, 29, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[10358, 424, 213, 4, 71, "Input",
  CellTags->"Integrate"],
Cell[10574, 430, 63, 2, 49, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[10652, 435, 384, 11, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[11061, 450, 138, 3, 62, "Input",
  CellTags->"Integrate"],
Cell[11202, 455, 139, 3, 65, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[11378, 463, 97, 2, 50, "Input",
  CellTags->"Integrate"],
Cell[11478, 467, 538, 9, 38, "Message",
  CellTags->"Integrate"],
Cell[12019, 478, 75, 2, 49, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[12109, 483, 98, 1, 29, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[12232, 488, 142, 3, 62, "Input",
  CellTags->"Integrate"],
Cell[12377, 493, 300, 6, 124, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[12692, 502, 633, 17, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[13350, 523, 89, 2, 50, "Input",
  CellTags->"Integrate"],
Cell[13442, 527, 378, 7, 94, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[13857, 539, 114, 2, 62, "Input",
  CellTags->"Integrate"],
Cell[13974, 543, 399, 7, 36, "Message",
  CellTags->"Integrate"],
Cell[14376, 552, 115, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14540, 560, 111, 4, 46, "Subsubsection",
  CellTags->"Integrate"],
Cell[14654, 566, 326, 8, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[15005, 578, 100, 2, 65, "Input",
  CellTags->"Integrate"],
Cell[15108, 582, 400, 7, 41, "Message",
  CellTags->"Integrate"],
Cell[15511, 591, 142, 3, 68, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[15668, 597, 314, 6, 48, "Text",
  CellTags->"Integrate"],

Cell[CellGroupData[{
Cell[16007, 607, 146, 4, 65, "Input",
  CellTags->"Integrate"],
Cell[16156, 613, 112, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16317, 621, 71, 1, 45, "Subsubsection",
  CellTags->"Integrate"],
Cell[16391, 624, 186, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[16602, 633, 105, 2, 62, "Input",
  CellTags->"Integrate"],
Cell[16710, 637, 106, 2, 62, "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[CellGroupData[{
Cell[16853, 644, 92, 2, 50, "Input",
  CellTags->"Integrate"],
Cell[16948, 648, 78, 2, 49, "Output",
  CellTags->"Integrate"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

