(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11729,        361]*)
(*NotebookOutlinePosition[     14576,        448]*)
(*  CellTagsIndexPosition[     14476,        441]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Note-13"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Fourier", "Subsubsection",
  CellTags->{"S0.1200", "Fourier"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["Fourier[", "MR"],
  StyleBox["list", "TI"],
  StyleBox["]", "MR"],
  " finds the discrete Fourier transform of a list of complex numbers. \n\
\[FilledSmallSquare] The discrete Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`v\_s\)], "InlineFormula"],
  " of a list ",
  Cell[BoxData[
      \(TraditionalForm\`u\_r\)], "InlineFormula"],
  " of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula"],
  " is by default defined to be ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(1\/\@n\), 
          UnderoverscriptBox["\[Sum]", \(r = 1\), "n",
            
            LimitsPositioning->
              True], \(u\_r\), \(e\^\(2  \[Pi] \( i(r - 1)\) \((s - 1)\)/
                  n\)\)}], TraditionalForm]], "InlineFormula"],
  ". \n\[FilledSmallSquare] Note that the zero frequency term appears at \
position 1 in the resulting list. \n\[FilledSmallSquare] Other definitions \
are used in some scientific and technical fields. \n\[FilledSmallSquare] \
Different choices of definitions can be specified using the option ",
  StyleBox["FourierParameters", "MR"],
  ". \n\[FilledSmallSquare] With the setting ",
  StyleBox["FourierParameters", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["a", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["b", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  " the discrete Fourier transform computed by ",
  StyleBox["Fourier", "MR"],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(1\/n\^\(\((1 - a)\)/2\)\), 
          UnderoverscriptBox["\[Sum]", \(r = 1\), "n",
            
            LimitsPositioning->
              True], \(u\_r\), \(e\^\(2  \[Pi]  
                i \( b(r - 1)\) \((s - 1)\)/n\)\)}], TraditionalForm]], 
    "InlineFormula"],
  ". \n\[FilledSmallSquare] Some common choices for ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["a", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["b", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  " are ",
  StyleBox["{0,", "MR"],
  " ",
  StyleBox["1}", "MR"],
  " (default), ",
  StyleBox["{-1,", "MR"],
  " ",
  StyleBox["1}", "MR"],
  " (data analysis), ",
  StyleBox["{1,", "MR"],
  " ",
  StyleBox["-1}", "MR"],
  " (signal processing). \n\[FilledSmallSquare] The setting ",
  Cell[BoxData[
      \(TraditionalForm\`b = \(-1\)\)], "InlineFormula"],
  " effectively corresponds to conjugating both input and output lists. \n\
\[FilledSmallSquare] To ensure a unique inverse discrete Fourier transform, \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[VerticalSeparator]\)\(b\)\(\[VerticalSeparator]\
\)\)\)], "InlineFormula"],
  " must be relatively prime to ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula"],
  ". \n\[FilledSmallSquare] The list of data supplied to ",
  StyleBox["Fourier", "MR"],
  " need not have a length equal to a power of two. \n\[FilledSmallSquare] \
The ",
  StyleBox["list", "TI"],
  " given in ",
  StyleBox["Fourier[", "MR"],
  StyleBox["list", "TI"],
  StyleBox["]", "MR"],
  " can be nested to represent an array of data in any number of dimensions. \
\n\[FilledSmallSquare] The array of data must be rectangular. \n\
\[FilledSmallSquare] If the elements of ",
  StyleBox["list", "TI"],
  " are exact numbers, ",
  StyleBox["Fourier", "MR"],
  " begins by applying ",
  StyleBox["N", "MR"],
  " to them. "
}], "Text",
  CellTags->{"S0.1200", "Fourier"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Further Examples", "Subsubsection",
  CellTags->"Fourier"],

Cell["Here is some sample data. ", "Text",
  CellTags->"Fourier"],

Cell[BoxData[
    \(\(data = {1.3, 2.4, 1.7, 4.1, 2.9, 1.7, 5.1, 2.7};\)\)], "Input",
  CellTags->"Fourier"],

Cell["\<\
This computes the discrete Fourier transform of the data. In general, the \
result is a list of complex numbers. \
\>", "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fourier[data]\)], "Input",
  CellTags->"Fourier"],

Cell[BoxData[
    \({\(\(7.742819253992695`\)\(\[InvisibleSpace]\)\) + 
        0.`\ \[ImaginaryI], \(-0.740685424949238`\) - 
        0.6770815280171307`\ \[ImaginaryI], \(-0.9192388155425117`\) - 
        0.9545941546018393`\ \[ImaginaryI], \(-0.39068542494923814`\) + 
        1.7270815280171306`\ \[ImaginaryI], \(\(0.03535533905932757`\)\(\
\[InvisibleSpace]\)\) + 0.`\ \[ImaginaryI], \(-0.39068542494923814`\) - 
        1.7270815280171306`\ \[ImaginaryI], \(-0.9192388155425117`\) + 
        0.9545941546018393`\ \[ImaginaryI], \(-0.740685424949238`\) + 
        0.6770815280171307`\ \[ImaginaryI]}\)], "Output",
  CellTags->"Fourier"]
}, Closed]],

Cell[TextData[{
  StyleBox["Chop", "MR"],
  " is used to discard the tiny imaginary parts that appear due to numerical \
error. "
}], "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[%]\)], "Input",
  CellTags->"Fourier"],

Cell[BoxData[
    \({7.742819253992695`, \(-0.740685424949238`\) - 
        0.6770815280171307`\ \[ImaginaryI], \(-0.9192388155425117`\) - 
        0.9545941546018393`\ \[ImaginaryI], \(-0.39068542494923814`\) + 
        1.7270815280171306`\ \[ImaginaryI], 
      0.03535533905932757`, \(-0.39068542494923814`\) - 
        1.7270815280171306`\ \[ImaginaryI], \(-0.9192388155425117`\) + 
        0.9545941546018393`\ \[ImaginaryI], \(-0.740685424949238`\) + 
        0.6770815280171307`\ \[ImaginaryI]}\)], "Output",
  CellTags->"Fourier"]
}, Closed]],

Cell["\<\
As a check here is the computation of the discrete Fourier transform directly \
from the definition. \
\>", "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{

Cell[BoxData[
    \(With[{n = Length[data]}, 
      Table[\[Sum]\+\(r = 1\)\%n \[ExponentialE]\^\(\(2\ \[Pi]\ \[ImaginaryI]\
\ \ \((r - 1)\)\ \((s - 1)\)\)\/n\)\ data\[LeftDoubleBracket]r\ \
\[RightDoubleBracket], {s, n}]\/\@n]\)], "Input",
  CellTags->"Fourier"],

Cell[BoxData[
    \({7.742819253992695`, \(-0.7406854249492377`\) - 
        0.6770815280171312`\ \[ImaginaryI], \(-0.9192388155425117`\) - 
        0.9545941546018393`\ \[ImaginaryI], \(-0.39068542494923797`\) + 
        1.7270815280171306`\ \[ImaginaryI], 
      0.03535533905932725`, \(-0.39068542494923797`\) - 
        1.7270815280171306`\ \[ImaginaryI], \(-0.9192388155425117`\) + 
        0.9545941546018393`\ \[ImaginaryI], \(-0.7406854249492377`\) + 
        0.6770815280171312`\ \[ImaginaryI]}\)], "Output",
  CellTags->"Fourier"]
}, Closed]],

Cell["This returns the original data. ", "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[InverseFourier[%]]\)], "Input",
  CellTags->"Fourier"],

Cell[BoxData[
    \({1.3000000000000003`, 2.4000000000000004`, 1.7`, 4.1000000000000005`, 
      2.8999999999999995`, 1.7000000000000002`, 5.1000000000000005`, 
      2.7000000000000006`}\)], "Output",
  CellTags->"Fourier"]
}, Closed]],

Cell["\<\
This gives the discrete Fourier transform of the data with Fourier parameters \
as used in signal processing. \
\>", "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[Fourier[data, FourierParameters -> {1, \(-1\)}]]\)], "Input",
  CellTags->"Fourier"],

Cell[BoxData[
    \({21.9`, \(-2.094974746830583`\) + 
        1.91507575950825`\ \[ImaginaryI], \(-2.5999999999999996`\) + 
        2.7`\ \[ImaginaryI], \(-1.105025253169417`\) - 
        4.884924240491749`\ \[ImaginaryI], 
      0.10000000000000053`, \(-1.105025253169417`\) + 
        4.884924240491749`\ \[ImaginaryI], \(-2.5999999999999996`\) - 
        2.7`\ \[ImaginaryI], \(-2.094974746830583`\) - 
        1.91507575950825`\ \[ImaginaryI]}\)], "Output",
  CellTags->"Fourier"]
}, Closed]],

Cell["\<\
Here is an example in two dimensions such as might come up in analyzing light \
passing through an aperture. \
\>", "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data2 = 
      Table[If[\((i - 3)\)\^2 + \((j - 3)\)\^2 < 4, 1, 0], {i, 6}, {j, 
          6}]\)], "Input",
  CellTags->"Fourier"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0, 0}, {0, 1, 1, 1, 0, 0}, {0, 1, 1, 1, 0, 0}, {0, 1, 1, 
        1, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}\)], "Output",
  CellTags->"Fourier"]
}, Closed]],

Cell["\<\
This gives the two\[Hyphen]dimensional discrete Fourier transform. \
\>", "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[Fourier[data2]]\)], "Input",
  CellTags->"Fourier"],

Cell[BoxData[
    \({{1.5`, \(-0.5`\) + 0.8660254037844386`\ \[ImaginaryI], 0, \(-0.5`\), 
        0, \(-0.5`\) - 0.8660254037844386`\ \[ImaginaryI]}, {\(-0.5`\) + 
          0.8660254037844386`\ \[ImaginaryI], \(-0.33333333333333326`\) - 
          0.5773502691896257`\ \[ImaginaryI], 
        0, \(\(0.16666666666666666`\)\(\[InvisibleSpace]\)\) - 
          0.28867513459481287`\ \[ImaginaryI], 0, 0.6666666666666665`}, {0, 
        0, 0, 0, 0, 
        0}, {\(-0.5`\), \(\(0.16666666666666666`\)\(\[InvisibleSpace]\)\) - 
          0.28867513459481287`\ \[ImaginaryI], 0, 0.16666666666666666`, 
        0, \(\(0.16666666666666666`\)\(\[InvisibleSpace]\)\) + 
          0.28867513459481287`\ \[ImaginaryI]}, {0, 0, 0, 0, 0, 
        0}, {\(-0.5`\) - 0.8660254037844386`\ \[ImaginaryI], 
        0.6666666666666665`, 
        0, \(\(0.16666666666666666`\)\(\[InvisibleSpace]\)\) + 
          0.28867513459481287`\ \[ImaginaryI], 
        0, \(-0.33333333333333326`\) + 
          0.5773502691896257`\ \[ImaginaryI]}}\)], "Output",
  CellTags->"Fourier"]
}, Closed]],

Cell[BoxData[{
    \(\(Clear[data, data2];\)\), "\[IndentingNewLine]", 
    \(\(Quit[];\)\)}], "Input",
  CellTags->"Fourier"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{642, 627},
WindowMargins->{{2, Automatic}, {Automatic, 2}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S0.1200"->{
    Cell[1899, 61, 68, 1, 45, "Subsubsection",
      CellTags->{"S0.1200", "Fourier"}],
    Cell[1970, 64, 3572, 106, 433, "Text",
      CellTags->{"S0.1200", "Fourier"}]},
  "Fourier"->{
    Cell[1899, 61, 68, 1, 45, "Subsubsection",
      CellTags->{"S0.1200", "Fourier"}],
    Cell[1970, 64, 3572, 106, 433, "Text",
      CellTags->{"S0.1200", "Fourier"}],
    Cell[5579, 175, 64, 1, 45, "Subsubsection",
      CellTags->"Fourier"],
    Cell[5646, 178, 65, 1, 29, "Text",
      CellTags->"Fourier"],
    Cell[5714, 181, 108, 2, 50, "Input",
      CellTags->"Fourier"],
    Cell[5825, 185, 160, 4, 29, "Text",
      CellTags->"Fourier"],
    Cell[6010, 193, 69, 2, 50, "Input",
      CellTags->"Fourier"],
    Cell[6082, 197, 642, 10, 87, "Output",
      CellTags->"Fourier"],
    Cell[6739, 210, 164, 5, 29, "Text",
      CellTags->"Fourier"],
    Cell[6928, 219, 63, 2, 50, "Input",
      CellTags->"Fourier"],
    Cell[6994, 223, 538, 9, 87, "Output",
      CellTags->"Fourier"],
    Cell[7547, 235, 148, 4, 29, "Text",
      CellTags->"Fourier"],
    Cell[7720, 243, 263, 5, 89, "Input",
      CellTags->"Fourier"],
    Cell[7986, 250, 540, 9, 87, "Output",
      CellTags->"Fourier"],
    Cell[8541, 262, 71, 1, 29, "Text",
      CellTags->"Fourier"],
    Cell[8637, 267, 79, 2, 50, "Input",
      CellTags->"Fourier"],
    Cell[8719, 271, 224, 4, 49, "Output",
      CellTags->"Fourier"],
    Cell[8958, 278, 157, 4, 29, "Text",
      CellTags->"Fourier"],
    Cell[9140, 286, 109, 2, 50, "Input",
      CellTags->"Fourier"],
    Cell[9252, 290, 485, 9, 68, "Output",
      CellTags->"Fourier"],
    Cell[9752, 302, 156, 4, 29, "Text",
      CellTags->"Fourier"],
    Cell[9933, 310, 150, 4, 51, "Input",
      CellTags->"Fourier"],
    Cell[10086, 316, 186, 3, 68, "Output",
      CellTags->"Fourier"],
    Cell[10287, 322, 114, 3, 29, "Text",
      CellTags->"Fourier"],
    Cell[10426, 329, 76, 2, 50, "Input",
      CellTags->"Fourier"],
    Cell[10505, 333, 1055, 18, 144, "Output",
      CellTags->"Fourier"],
    Cell[11575, 354, 126, 3, 70, "Input",
      CellTags->"Fourier"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S0.1200", 12356, 377},
  {"Fourier", 12544, 382}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 98, 4, 52, "Subsection"],

Cell[CellGroupData[{
Cell[1899, 61, 68, 1, 45, "Subsubsection",
  CellTags->{"S0.1200", "Fourier"}],
Cell[1970, 64, 3572, 106, 433, "Text",
  CellTags->{"S0.1200", "Fourier"}]
}, Closed]],

Cell[CellGroupData[{
Cell[5579, 175, 64, 1, 45, "Subsubsection",
  CellTags->"Fourier"],
Cell[5646, 178, 65, 1, 29, "Text",
  CellTags->"Fourier"],
Cell[5714, 181, 108, 2, 50, "Input",
  CellTags->"Fourier"],
Cell[5825, 185, 160, 4, 29, "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{
Cell[6010, 193, 69, 2, 50, "Input",
  CellTags->"Fourier"],
Cell[6082, 197, 642, 10, 87, "Output",
  CellTags->"Fourier"]
}, Closed]],
Cell[6739, 210, 164, 5, 29, "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{
Cell[6928, 219, 63, 2, 50, "Input",
  CellTags->"Fourier"],
Cell[6994, 223, 538, 9, 87, "Output",
  CellTags->"Fourier"]
}, Closed]],
Cell[7547, 235, 148, 4, 29, "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{
Cell[7720, 243, 263, 5, 89, "Input",
  CellTags->"Fourier"],
Cell[7986, 250, 540, 9, 87, "Output",
  CellTags->"Fourier"]
}, Closed]],
Cell[8541, 262, 71, 1, 29, "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{
Cell[8637, 267, 79, 2, 50, "Input",
  CellTags->"Fourier"],
Cell[8719, 271, 224, 4, 49, "Output",
  CellTags->"Fourier"]
}, Closed]],
Cell[8958, 278, 157, 4, 29, "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{
Cell[9140, 286, 109, 2, 50, "Input",
  CellTags->"Fourier"],
Cell[9252, 290, 485, 9, 68, "Output",
  CellTags->"Fourier"]
}, Closed]],
Cell[9752, 302, 156, 4, 29, "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{
Cell[9933, 310, 150, 4, 51, "Input",
  CellTags->"Fourier"],
Cell[10086, 316, 186, 3, 68, "Output",
  CellTags->"Fourier"]
}, Closed]],
Cell[10287, 322, 114, 3, 29, "Text",
  CellTags->"Fourier"],

Cell[CellGroupData[{
Cell[10426, 329, 76, 2, 50, "Input",
  CellTags->"Fourier"],
Cell[10505, 333, 1055, 18, 144, "Output",
  CellTags->"Fourier"]
}, Closed]],
Cell[11575, 354, 126, 3, 70, "Input",
  CellTags->"Fourier"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

