(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5859,        206]*)
(*NotebookOutlinePosition[      6540,        229]*)
(*  CellTagsIndexPosition[      6496,        225]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Note-3"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Kinetic energies", "Subsubsection"],

Cell["Energy stored in linear motion of a mas m is", "Text"],

Cell[BoxData[
    \(\(lm[m_, x_] := \((1/2)\)*m*D[x[t], t]^2;\)\)], "Input"],

Cell["Energy stored in rotational motion of a inertia j is", "Text"],

Cell[BoxData[
    \(\(rm[j_, o_] := \((1/2)\)*j*D[o[t], t]^2;\)\)], "Input"],

Cell["Energy stored in electrical system with a inductance el is", "Text"],

Cell[BoxData[
    \(\(em[el_, q_] := \((1/2)\)*el*D[q[t], t]^2;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Potential energies", "Subsubsection"],

Cell["Energy stored in linear motion of a spring k is", "Text"],

Cell[BoxData[
    \(\(ls[k_, x_] := \((1/2)\)*k*x[t]^2;\)\)], "Input"],

Cell["Energy stored in rotational motion of a spring ck is", "Text"],

Cell[BoxData[
    \(\(rs[ck_, o_] := \((1/2)\)*ck*o[t]^2;\)\)], "Input"],

Cell["Energy stored in electrical circuit of a capacitor ec is", "Text"],

Cell[BoxData[
    \(\(es[ec_, q_] := \((1/2)\)*\((1. /ec)\)*q[t]^2;\)\)], "Input"],

Cell["Entire Lagrangian is given by", "Text"],

Cell[BoxData[
    \(\(l[m_, j_, el_, k_, ck_, ec_, x_, o_, q_] := 
        lm[m, x] + rm[j, o] + em[el, q] - ls[k, x] - rs[ck, o] - 
          es[ec, q];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rayleigh's dissipative function", "Subsubsection"],

Cell["\<\
Rayleigh dissipative function in linear motion with friction coefficient b is\
\
\>", "Text"],

Cell[BoxData[
    \(\(lf[b_, x_] := \((1/2)\)*b*D[x[t], t]^2;\)\)], "Input"],

Cell["\<\
Rayleigh dissipative function in rotational motion with friction coefficient \
rb is\
\>", "Text"],

Cell[BoxData[
    \(\(rf[rb_, o_] := \((1/2)\)*rb*D[o[t], t]^2;\)\)], "Input"],

Cell["\<\
Rayleigh dissipative function in electrical circuit with resistance eb is\
\>", "Text"],

Cell[BoxData[
    \(\(re[eb_, q_] := \((1/2)\)*eb*D[q[t], t]^2;\)\)], "Input"],

Cell["Entire dissipative function is given by", "Text"],

Cell[BoxData[
    \(\(f[b_, rb_, eb_, x_, o_, q_] := 
        lf[b, x] + rf[rb, o] + re[eb, q];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["System of equations", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[D[l[M, J, L, K, cK, C, x, omg, q], D[x[t], t]], t] - 
      D[l[M, J, L, K, cK, C, x, omg, q], x[t]] + 
      D[f[B, rB, R, x, omg, q], D[x[t], t]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(K\ x[t]\), "+", 
      RowBox[{"B", " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"M", " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[D[l[M, J, L, K, cK, C, x, omg, q], D[omg[t], t]], t] - 
      D[l[M, J, L, K, cK, C, x, omg, q], omg[t]] + 
      D[f[B, rB, R, x, omg, q], D[omg[t], t]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(cK\ omg[t]\), "+", 
      RowBox[{"rB", " ", 
        RowBox[{
          SuperscriptBox["omg", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"J", " ", 
        RowBox[{
          SuperscriptBox["omg", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[D[l[M, J, L, K, cK, C, x, omg, q], D[q[t], t]], t] - 
      D[l[M, J, L, K, cK, C, x, omg, q], q[t]] + 
      D[f[B, rB, R, x, omg, q], D[q[t], t]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(1.`\ q[t]\)\/C\), "+", 
      RowBox[{"R", " ", 
        RowBox[{
          SuperscriptBox["q", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"L", " ", 
        RowBox[{
          SuperscriptBox["q", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(Quit[];\)\)], "Input"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{650, 627},
WindowMargins->{{18, Automatic}, {Automatic, 23}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 97, 4, 52, "Subsection"],

Cell[CellGroupData[{
Cell[1898, 61, 41, 0, 45, "Subsubsection"],
Cell[1942, 63, 60, 0, 29, "Text"],
Cell[2005, 65, 76, 1, 50, "Input"],
Cell[2084, 68, 68, 0, 29, "Text"],
Cell[2155, 70, 76, 1, 50, "Input"],
Cell[2234, 73, 74, 0, 29, "Text"],
Cell[2311, 75, 78, 1, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2426, 81, 43, 0, 45, "Subsubsection"],
Cell[2472, 83, 63, 0, 29, "Text"],
Cell[2538, 85, 70, 1, 50, "Input"],
Cell[2611, 88, 68, 0, 29, "Text"],
Cell[2682, 90, 72, 1, 50, "Input"],
Cell[2757, 93, 72, 0, 29, "Text"],
Cell[2832, 95, 82, 1, 50, "Input"],
Cell[2917, 98, 45, 0, 29, "Text"],
Cell[2965, 100, 168, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3170, 108, 56, 0, 45, "Subsubsection"],
Cell[3229, 110, 103, 3, 29, "Text"],
Cell[3335, 115, 76, 1, 50, "Input"],
Cell[3414, 118, 108, 3, 29, "Text"],
Cell[3525, 123, 78, 1, 50, "Input"],
Cell[3606, 126, 97, 2, 29, "Text"],
Cell[3706, 130, 78, 1, 50, "Input"],
Cell[3787, 133, 55, 0, 29, "Text"],
Cell[3845, 135, 110, 2, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3992, 142, 44, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[4061, 146, 182, 3, 90, "Input"],
Cell[4246, 151, 353, 9, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4636, 165, 188, 3, 90, "Input"],
Cell[4827, 170, 361, 9, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[5225, 184, 182, 3, 90, "Input"],
Cell[5410, 189, 362, 9, 62, "Output"]
}, Closed]],
Cell[5787, 201, 44, 1, 50, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

