(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     49974,       1265]*)
(*NotebookOutlinePosition[     50676,       1289]*)
(*  CellTagsIndexPosition[     50632,       1285]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Note-8"
}], "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Lagrangian and Rayleigh's dissipative function in linear motion system\
\>", "Subsubsection"],

Cell["Kinetic energy:", "Text"],

Cell[BoxData[
    \(\(kineticEnergy[m_, x_] := \((1/2)\)*m*\((D[x[t], t]^2)\);\)\)], "Input"],

Cell["Potential energy:", "Text"],

Cell[BoxData[
    \(\(potentialEnergy[k_, x_] := \((1/2)\)*k*\((x[t]^2)\);\)\)], "Input"],

Cell["Lagrangian:", "Text"],

Cell[BoxData[
    \(\(l[m_, k_, x_] := 
        kineticEnergy[m, x] - potentialEnergy[k, x];\)\)], "Input"],

Cell["Rayleigh dissipative function:", "Text"],

Cell[BoxData[
    \(\(f[b_, x_] := \((1/2)\)*b*\((D[x[t], t]^2)\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["System of equations", "Subsubsection"],

Cell["Linear motion system:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[D[l[M, K, x], D[x[t], t]], t] - D[l[M, K, x], x[t]] + 
      D[f[B, x], D[x[t], t]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(K\ x[t]\), "+", 
      RowBox[{"B", " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"M", " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Homogeneous liner speed motion", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hlS = 
      D[D[l[M, 0. , x], \(x'\)[t]], t] + D[f[B, x], \(x'\)[t]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"B", " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"M", " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output"]
}, Closed]],

Cell[BoxData[{
    \(\(B = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[1] = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[2] = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(solution = 
        D[DSolve[hlS \[Equal] 0, x[t], t, GeneratedParameters \[Rule] Con], 
          t];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[\(x'\)[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 1.17721 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.1)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.2)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.3)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.4)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57977 m
.02756 .57977 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .52887 L
.10458 .45837 L
.14415 .40099 L
.18221 .35282 L
.22272 .30813 L
.26171 .2707 L
.30316 .23613 L
.34309 .20725 L
.3815 .18303 L
.42237 .1606 L
.46172 .14183 L
.49955 .12606 L
.53984 .11142 L
.57861 .09915 L
.61984 .0878 L
.65954 .07832 L
.69774 .07036 L
.73838 .06298 L
.77751 .0568 L
.81909 .0511 L
.85916 .04634 L
.89771 .04235 L
.93871 .03866 L
.97619 .03571 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00A`3oool400000380oooo0`00000^0?ooo`<00000<P3oool2000002h0oooo1@0000020?oo
o`800000103oool004L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`04
0000003oool0oooo00000300oooo00@000000?ooo`3oool00000;`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00@3oool004P0oooo00<000000?ooo`3oool0<03oool5
000002h0oooo00@000000?ooo`3oool00000<03oool010000000oooo0?ooo`00000_0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`00B@3oool00`000000oooo
0?ooo`0_0?ooo`040000003oool0oooo000002l0oooo0`00000b0?ooo`800000<03oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool004L0oooo00@000000?ooo`3o
ool00000<@3oool00`000000oooo0000000`0?ooo`030000003oool0oooo0300oooo00@000000?oo
o`3oool00000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3o
ool004P0oooo0P00000c0?ooo`800000<03oool300000340oooo0P00000_0?ooo`800000103oool2
000000@0oooo003o0?ooob40oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E
0?ooo`030000003oool0oooo0?l0oooo2@3oool000l0ooooo`00000A00000040oooo000E0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
1@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo0P00003b0?oooa00
00001`3oool001D0oooo00<000000?ooo`3oool0j@3oool8000001L0oooo000E0?ooo`030000003o
ool0oooo0><0oooo1P00000O0?ooo`005@3oool00`000000oooo0?ooo`3K0?ooo`P000009@3oool0
01D0oooo00<000000?ooo`3oool0d03oool;000002d0oooo000E0?ooo`030000003oool0oooo0<P0
oooo2000000h0?ooo`005@3oool00`000000oooo0?ooo`320?ooo`H00000@03oool001D0oooo0P00
002n0?ooo`D00000AP3oool001D0oooo00<000000?ooo`3oool0]`3oool6000004/0oooo000E0?oo
o`030000003oool0oooo0;80oooo1@00001A0?ooo`005@3oool00`000000oooo0?ooo`2]0?ooo`D0
0000EP3oool001D0oooo00<000000?ooo`3oool0Z@3oool4000005/0oooo000E0?ooo`030000003o
ool0oooo0:D0oooo1000001O0?ooo`005@3oool200000:80oooo1000001S0?ooo`005@3oool00`00
0000oooo0?ooo`2N0?ooo`<00000I`3oool001D0oooo00<000000?ooo`3oool0VP3oool4000006X0
oooo000E0?ooo`030000003oool0oooo09H0oooo1000001^0?ooo`005@3oool00`000000oooo0?oo
o`2C0?ooo`<00000LP3oool001D0oooo00<000000?ooo`3oool0S`3oool4000007D0oooo000E0?oo
o`030000003oool0oooo08/0oooo1000001i0?ooo`005@3oool2000008T0oooo0`00001m0?ooo`00
5@3oool00`000000oooo0?ooo`250?ooo`<00000P03oool001D0oooo00<000000?ooo`3oool0P`3o
ool2000008<0oooo000E0?ooo`030000003oool0oooo0800oooo0`0000250?ooo`000P3oool20000
00@0oooo0P0000030?ooo`D000000`3oool00`000000oooo0?ooo`1n0?ooo`800000R03oool00005
0?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
07`0oooo0P00002:0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo
00<0oooo0`00001j0?ooo`800000S03oool000050?ooo`000000oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07P0oooo0P00002>0?ooo`0000D0oooo0000003o
ool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0MP3oool20000
0900oooo00020?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0L`3oool300000980
oooo000E0?ooo`030000003oool0oooo0740oooo0P00002E0?ooo`005@3oool00`000000oooo0?oo
o`1_0?ooo`800000U`3oool001D0oooo0P00001^0?ooo`800000V@3oool001D0oooo00<000000?oo
o`3oool0J`3oool2000009/0oooo000E0?ooo`030000003oool0oooo06T0oooo0P00002M0?ooo`00
5@3oool00`000000oooo0?ooo`1W0?ooo`800000W`3oool001D0oooo00<000000?ooo`3oool0I@3o
ool200000:40oooo000E0?ooo`030000003oool0oooo06<0oooo0P00002S0?ooo`005@3oool00`00
0000oooo0?ooo`1Q0?ooo`800000Y@3oool001D0oooo0P00001P0?ooo`800000Y`3oool001D0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`2W0?ooo`005@3oool00`000000oooo0?oo
o`1L0?ooo`800000ZP3oool001D0oooo00<000000?ooo`3oool0FP3oool200000:`0oooo000E0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0[03oool001D0oooo00<000000?ooo`3o
ool0E`3oool200000:l0oooo000E0?ooo`800000EP3oool200000;40oooo000E0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0/@3oool001D0oooo00<000000?ooo`3oool0DP3oool2
00000;@0oooo000E0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0]03oool001D0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2e0?ooo`005@3oool00`000000oooo
0?ooo`1>0?ooo`800000^03oool001D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`2h0?ooo`005@3oool2000004d0oooo00<000000?ooo`3oool0^@3oool001D0oooo00<000000?oo
o`3oool0BP3oool200000;`0oooo000E0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0_03oool001D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2m0?ooo`000P3o
ool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0;h0oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0;l0oooo00001@3oool000000?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0103oool3000004D0oooo00<000000?ooo`3oool0`03o
ool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04<0oooo0P0000330?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`330?ooo`000P3o
ool2000000X0oooo0P0000050?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0a03o
ool001D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`350?ooo`005@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0<H0oooo000E0?ooo`800000?`3oool00`000000
oooo0?ooo`370?ooo`005@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0<P0oooo
000E0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0b@3oool001D0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`3:0?ooo`005@3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0</0oooo000E0?ooo`030000003oool0oooo03P0oooo0P00003>0?ooo`00
5@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0<h0oooo000E0?ooo`800000=`3o
ool00`000000oooo0?ooo`3?0?ooo`005@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0=00oooo000E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0d@3oool001D0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3B0?ooo`005@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0=<0oooo000E0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0e03oool001D0oooo0P00000a0?ooo`030000003oool0oooo0=D0oooo000E0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0eP3oool001D0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`3G0?ooo`005@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0=P0oooo000E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0f03o
ool001D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3I0?ooo`005@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0=X0oooo000E0?ooo`800000:`3oool00`000000
oooo0?ooo`3K0?ooo`005@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=`0oooo
000E0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0g@3oool001D0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`3N0?ooo`000P3oool2000000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=l0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0=l0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool00`3oool3000002D0oooo00<000000?ooo`3oool0h03oool000050?ooo`000000oooo
0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0h@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0hP3oool00080oooo0P00000:
0?ooo`8000001@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0>80oooo000E0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0h`3oool001D0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`3T0?ooo`005@3oool200000240oooo00<000000?ooo`3oool0
i@3oool001D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3U0?ooo`005@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0>H0oooo000E0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0i`3oool001D0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`3X0?ooo`005@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0>P0oooo
000E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0j@3oool001D0oooo0P00000L
0?ooo`030000003oool0oooo0>X0oooo000E0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0jP3oool001D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3[0?ooo`00
5@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0>`0oooo000E0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0k@3oool001D0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`3]0?ooo`005@3oool2000001P0oooo00<000000?ooo`3oool0kP3oool001D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3_0?ooo`005@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0>l0oooo000E0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0l03oool001D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3a
0?ooo`005@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?40oooo000E0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0lP3oool001D0oooo0P00000C0?ooo`030000
003oool0oooo0?<0oooo000E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0l`3o
ool001D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3d0?ooo`005@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0?D0oooo00020?ooo`800000103oool2000000D0
oooo0`0000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0m@3oool000050?oo
o`000000oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0mP3oool000050?ooo`000000oooo0?ooo`000000203oool5000000<0
oooo0`00000?0?ooo`030000003oool0oooo0?H0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0?L0oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?P0oooo00020?ooo`8000002`3oool2000000@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3h0?ooo`005@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0?T0oooo000E0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0nP3oool001D0oooo0P00000<0?ooo`030000003oool0oooo0?X0oooo000E0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0n`3oool001D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3k0?ooo`005@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0?`0oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o@3o
ool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3m0?ooo`005@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0?h0oooo000E0?ooo`8000001`3oool00`000000
oooo0?ooo`3o0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo
000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool10?ooo`005@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo0@3oool001D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?ooo`80oooo000E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3oool20?ooo`005@3oool2000000@0oooo00<000000?ooo`3oool0
o`3oool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3o
ool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?ooo`005@3oool01@000000
oooo0?ooo`3oool000000?l0oooo1`3oool001D0oooo00D000000?ooo`3oool0oooo0000003o0?oo
o`L0oooo000E0?ooo`040000003oool0oooo00000?l0oooo203oool001D0oooo0P0000000`3oool0
00000?ooo`3o0?ooo`L0oooo000E0?ooo`030000003oool000000?l0oooo2@3oool001D0oooo00<0
00000?ooo`000000o`3oool90?ooo`005@3oool200000?l0oooo2P3oool00080oooo0P0000040?oo
o`800000103oool2000000D0oooo0P00003o0?ooo`X0oooo00001@3oool000000?ooo`3oool00000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo00001@3o
ool000000?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool300000?l0oooo2@3oool0
00050?ooo`000000oooo0?ooo`0000002@3oool2000000D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`000P3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.829852, -0.0387349, \
0.0386179, 0.00312425}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Homogeneous vibrating motion", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 2. ;\)\), "\[IndentingNewLine]", 
    \(hvS = D[D[l[M, K, x], D[x[t], t]], t] - D[l[M, K, x], x[t]]\)}], "Input"],

Cell[BoxData[
    RowBox[{\(2.`\ x[t]\), "+", 
      RowBox[{"1.5`", " ", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution = 
      DSolve[hvS \[Equal] 0, x[t], t, 
        GeneratedParameters \[Rule] Con]\)], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          0.5`\ \[ExponentialE]\^\(0.`\ t\)\ Cos[1.1547005383792515`\ t] + 
            1.5`\ \[ExponentialE]\^\(0.`\ t\)\ Sin[
                1.1547005383792515`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.186134 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 .02982 -24 -4.5 ]
[.01131 .02982 0 4.5 ]
[.01131 .12288 -12 -4.5 ]
[.01131 .12288 0 4.5 ]
[.01131 .21595 -24 -4.5 ]
[.01131 .21595 0 4.5 ]
[.01131 .40208 -18 -4.5 ]
[.01131 .40208 0 4.5 ]
[.01131 .49515 -6 -4.5 ]
[.01131 .49515 0 4.5 ]
[.01131 .58822 -18 -4.5 ]
[.01131 .58822 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .02982 m
.03006 .02982 L
s
[(-1.5)] .01131 .02982 1 0 Mshowa
.02381 .12288 m
.03006 .12288 L
s
[(-1)] .01131 .12288 1 0 Mshowa
.02381 .21595 m
.03006 .21595 L
s
[(-0.5)] .01131 .21595 1 0 Mshowa
.02381 .40208 m
.03006 .40208 L
s
[(0.5)] .01131 .40208 1 0 Mshowa
.02381 .49515 m
.03006 .49515 L
s
[(1)] .01131 .49515 1 0 Mshowa
.02381 .58822 m
.03006 .58822 L
s
[(1.5)] .01131 .58822 1 0 Mshowa
.125 Mabswid
.02381 .04843 m
.02756 .04843 L
s
.02381 .06704 m
.02756 .06704 L
s
.02381 .08566 m
.02756 .08566 L
s
.02381 .10427 m
.02756 .10427 L
s
.02381 .1415 m
.02756 .1415 L
s
.02381 .16011 m
.02756 .16011 L
s
.02381 .17872 m
.02756 .17872 L
s
.02381 .19734 m
.02756 .19734 L
s
.02381 .23456 m
.02756 .23456 L
s
.02381 .25318 m
.02756 .25318 L
s
.02381 .27179 m
.02756 .27179 L
s
.02381 .2904 m
.02756 .2904 L
s
.02381 .32763 m
.02756 .32763 L
s
.02381 .34624 m
.02756 .34624 L
s
.02381 .36486 m
.02756 .36486 L
s
.02381 .38347 m
.02756 .38347 L
s
.02381 .4207 m
.02756 .4207 L
s
.02381 .43931 m
.02756 .43931 L
s
.02381 .45792 m
.02756 .45792 L
s
.02381 .47654 m
.02756 .47654 L
s
.02381 .51376 m
.02756 .51376 L
s
.02381 .53238 m
.02756 .53238 L
s
.02381 .55099 m
.02756 .55099 L
s
.02381 .5696 m
.02756 .5696 L
s
.02381 .0112 m
.02756 .0112 L
s
.02381 .60683 m
.02756 .60683 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40208 m
.04262 .46279 L
.06244 .51811 L
.08255 .56192 L
.09396 .58025 L
.09905 .58679 L
.10458 .59268 L
.11004 .59724 L
.11243 .59885 L
.11508 .60034 L
.1174 .6014 L
.11989 .60228 L
.12127 .60265 L
.12253 .60292 L
.12379 .60312 L
.125 .60325 L
.12617 .60331 L
.12723 .60332 L
.12845 .60326 L
.1296 .60315 L
.13067 .603 L
.13166 .60282 L
.13388 .60225 L
.13613 .60145 L
.13859 .60033 L
.14357 .59728 L
.14881 .59293 L
.15378 .58775 L
.16308 .57534 L
.1731 .55821 L
.184 .53541 L
.22478 .41906 L
.26405 .28173 L
.3018 .15505 L
.32277 .0969 L
.33195 .07555 L
.342 .05551 L
.35111 .04057 L
.36085 .02823 L
.36623 .02308 L
.37112 .01945 L
.37348 .01807 L
.37604 .01683 L
.37846 .01592 L
.38069 .01531 L
.38194 .01506 L
.38313 .01488 L
.3842 .01478 L
.38536 .01472 L
.38662 .01472 L
Mistroke
.38733 .01475 L
.38797 .0148 L
.38921 .01494 L
.39038 .01514 L
.39149 .01538 L
.39265 .01569 L
.39474 .01639 L
.39699 .01735 L
.39945 .01865 L
.40461 .02222 L
.41013 .02728 L
.42009 .03958 L
.43029 .05624 L
.44137 .0787 L
.4615 .12981 L
.50234 .26225 L
.54166 .40079 L
.57946 .51504 L
.59884 .55832 L
.60974 .57675 L
.61456 .58344 L
.61971 .58954 L
.62487 .59455 L
.62954 .59813 L
.6318 .59953 L
.63424 .60079 L
.63654 .60175 L
.63868 .60244 L
.63988 .60274 L
.64117 .60299 L
.64191 .60311 L
.64261 .60319 L
.64392 .60329 L
.64459 .60332 L
.6453 .60332 L
.64657 .60327 L
.64728 .60321 L
.64794 .60314 L
.64867 .60304 L
.64946 .6029 L
.65198 .60228 L
.65325 .60187 L
.65464 .60134 L
.65939 .59889 L
.66467 .59504 L
.66965 .59034 L
.67898 .57878 L
.68902 .56249 L
.69992 .54058 L
.74081 .42631 L
Mistroke
.78018 .28919 L
.81803 .16115 L
.83909 .10169 L
.85834 .059 L
.86785 .04279 L
.87288 .03565 L
.87823 .02915 L
.88337 .02402 L
.88803 .02033 L
.89029 .01887 L
.89272 .01755 L
.89503 .01652 L
.89713 .01579 L
.89827 .01547 L
.89951 .01518 L
.90081 .01496 L
.90205 .01481 L
.90321 .01473 L
.90444 .01472 L
.90549 .01475 L
.90665 .01485 L
.9073 .01493 L
.908 .01503 L
.90924 .01527 L
.91057 .0156 L
.91203 .01605 L
.91465 .01709 L
.91708 .01831 L
.92242 .02189 L
.92727 .02618 L
.93815 .03934 L
.94765 .05467 L
.95641 .07179 L
.97619 .11996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103o
ool001/0oooo00<000000?ooo`3oool0F`3oool6000008<0oooo1`00000G0?ooo`006`3oool00`00
0000oooo0?ooo`1I0?ooo`8000001P3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool05@3oool000L0oooo1@0000020?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07`0
oooo0P0000080?ooo`8000005@3oool000T0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo05H0oooo0P00000;0?ooo`800000N`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo00090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool2000005H0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool000030?ooo`00
0000000000800000103oool00`000000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo00090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00080?oo
o`8000002P3oool3000000@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?oo
o`006`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo000K0?ooo`800000
D`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0=0?ooo`006`3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00`0oooo000K0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool0
01/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0KP3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo000K0?ooo`800000D@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00T0oooo000K0?ooo`800000CP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`006`3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo000K0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`070?ooo`006`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0
oooo000K0?ooo`800000C03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`006`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01P3oool001<0oooo1@0000030?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool01@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo00<0oooo0P00001;0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0[0?ooo`003@3o
ool4000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0/0?ooo`005@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02`0oooo000D0?ooo`8000001@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0/0?ooo`006`3oool2000004T0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02d0oooo
000K0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo02h0oooo000K0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02h0oooo000K0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo02h0oooo000K0?ooo`800000B03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool001/0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
;`3oool001/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0;`3oool001/0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0<03oool0
01/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0<03oool001/0oooo0P0000160?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0`0?ooo`006`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0`0?ooo`006`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0a0?ooo`006`3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0a
0?ooo`006`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0a0?ooo`006`3oool2000004D0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0380oooo000K0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0380oooo000K0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0380oooo00080?ooo`800000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03<0oooo00070?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0c0?ooo`001`3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P0000130?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0c0?ooo`0000<0oooo
0000000000000P0000020?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo03<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0d0?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo03@0oooo000K0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo03@0oooo000K0?ooo`800000@P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0=@3oool001/0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0=@3oool001/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0=@3oool001/0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0=@3oool001/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0=P3oool001/0oooo0P0000100?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0f0?ooo`00
6`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`0f0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0g0?ooo`006`3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0g0?ooo`006`3oool00`000000oooo0?ooo`0]0?ooo`@000003@3oool00`00
0000oooo0?ooo`0Q0?ooo`<000005`3oool00`000000oooo0?ooo`0D0?ooo`<00000<03oool30000
02`0oooo1@0000020?ooo`800000103oool001/0oooo0P00000^0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01<0
oooo00@000000?ooo`3oool00000;P3oool010000000oooo00000000000^0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool07`3oool5000001P0oooo00<00000
0?ooo`3oool04`3oool010000000oooo0?ooo`00000^0?ooo`040000003oool00000000002h0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`040000
003oool0oooo000001T0oooo00<000000?ooo`3oool04`3oool300000300oooo0P00000_0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`0]0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0000000J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;P3oool01000
0000oooo00000000000^0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`010?ooo`006`3oool00`000000oooo0?ooo`0^0?ooo`8000003@3oool00`000000oooo0?ooo`0R
0?ooo`8000006P3oool00`000000oooo0?ooo`0C0?ooo`<00000;`3oool2000002h0oooo0P000004
0?ooo`800000103oool001/0oooo0P00000m0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0i0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0i0?ooo`00
6`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0j0?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0j0?ooo`006`3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0j0?ooo`00503ooooo000000d00000000K0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool2000000`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool001/0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02`0
oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`050?ooo`006`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0k0?ooo`006`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0l0?ooo`006`3oool2000003X0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03`0oooo000K
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo03`0oooo000K0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03`0oooo000K0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo03d0oooo000K0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo000K0?ooo`800000>@3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?@3o
ool001/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0?@3oool001/0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0?P3oool001/0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0?P3oool001/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0?P3oool001/0oooo0P00
000g0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0o0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0o0?ooo`006`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0o0?oo
o`006`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0o0?ooo`006`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`100?ooo`006`3o
ool2000003H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0400oooo000K0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0400oooo000K0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0440oooo00080?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0440
oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`110?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
0080oooo0P00000d0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`110?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`120?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00@0oooo0P00000d0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`120?ooo`00203oool2000000X0oooo0`0000040?ooo`800000<`3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0@P3oool001/0oooo
0P00000c0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`120?ooo`006`3oool300000380oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo04<0oooo000K0?ooo`030000003oool000000340oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo04<0oooo000K0?oo
o`030000003oool000000340oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo04<0oooo000K0?ooo`030000003oool000000340oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo04@0oooo000K0?ooo`040000
003oool0oooo000002l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo04@0oooo000K0?ooo`80000000<0oooo0000003oool0;P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0A03oool001/0oooo00@0
00000?ooo`3oool00000;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0A@3oool001/0oooo00D000000?ooo`3oool0oooo0000000]0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`150?ooo`006`3o
ool01@000000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo04D0oooo000K0?ooo`050000003oool0oooo0?ooo`000000
;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
AP3oool001/0oooo0P0000030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04H0oooo000K0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0A`3oool001/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`170?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04L0
oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0B03oool001/0oooo0P00
00040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo04P0oooo000K0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0B03oool001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`190?oo
o`004`3oool5000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`190?ooo`00
5@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
B@3oool001D0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0BP3o
ool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo04X0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`1:0?ooo`00503oool2000000D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`1;0?ooo`006`3oool2000000L0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0B`3oool001/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`1<0?ooo`006`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo04`0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0C03oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1=0?ooo`00
6`3oool2000000T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0C@3oool001/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1=0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo04h0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0CP3oool001/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1?0?ooo`006`3oool2000000`0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0C`3oool001/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1@0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0500oooo000K0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0D@3oool001/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`1B0?ooo`006`3oool2000000h0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
DP3oool001/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1C0?ooo`006`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05<0oooo00070?ooo`D000000P3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E03oool000T0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0E@3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`8000004P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1E0?ooo`002@3oool00`000000oooo
0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05H0oooo
00090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0N`3oool2000000T0oooo0P00
001I0?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1n0?ooo`8000001P3oool00`000000oooo0?ooo`1I
0?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`P00000PP3oool7000005`0oooo000K0?ooo`80
0000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07864, -1.7868, \
0.0394728, 0.0201968}}]
}, Closed]],

Cell[BoxData[
    \(\(Quit[];\)\)], "Input"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{689, 627},
WindowMargins->{{-3, Automatic}, {Automatic, -2}},
ShowSelection->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 97, 4, 52, "Subsection"],

Cell[CellGroupData[{
Cell[1898, 61, 103, 2, 45, "Subsubsection"],
Cell[2004, 65, 31, 0, 29, "Text"],
Cell[2038, 67, 93, 1, 50, "Input"],
Cell[2134, 70, 33, 0, 29, "Text"],
Cell[2170, 72, 89, 1, 50, "Input"],
Cell[2262, 75, 27, 0, 29, "Text"],
Cell[2292, 77, 107, 2, 50, "Input"],
Cell[2402, 81, 46, 0, 29, "Text"],
Cell[2451, 83, 81, 1, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2569, 89, 44, 0, 45, "Subsubsection"],
Cell[2616, 91, 37, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[2678, 95, 118, 2, 50, "Input"],
Cell[2799, 99, 353, 9, 49, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3201, 114, 55, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[3281, 118, 102, 2, 50, "Input"],
Cell[3386, 122, 335, 9, 49, "Output"]
}, Closed]],
Cell[3736, 134, 335, 7, 130, "Input"],

Cell[CellGroupData[{
Cell[4096, 145, 87, 1, 50, "Input"],
Cell[4186, 148, 16131, 402, 186, 3433, 241, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20366, 556, 53, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[20444, 560, 140, 2, 70, "Input"],
Cell[20587, 564, 211, 5, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[20835, 574, 124, 3, 50, "Input"],
Cell[20962, 579, 219, 4, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[21218, 588, 82, 1, 50, "Input"],
Cell[21303, 591, 28584, 666, 186, 5498, 376, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[49902, 1260, 44, 1, 50, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

